OPX Software
Preface
This document provides an overview of the changes introduced in this release. References to more detailed information are provided where necessary. The information contained in this document is intended as supplemental information only; it should be used in conjunction with the documentation provided for each component.
Software License Agreement
The software is provided under license agreements and may contain third-party software under separate third-party licensing. Refer to the license files provided with the software for specific details.
If You Need Help
Technical support for all Cornelis products is available 24 hours a day, 365 days a year.
For additional details:
Visit the Cornelis Support page at http://www.cornelisnetworks.com/support
Contact email: support@cornelisnetworks.com
New in This Release
The following features are new in this release:
Automatic Context Sharing
Refer to the CN5000 Performance Tuning Guide for details.
One-Sided RMA Acceleration over HFI Service (HFISVC)
Refer to the CN5000 Performance Tuning Guide for details.
Maintenance Updates
Release Items
The following software package is available for this release:
CN5000_OPXSoftware-<DISTRO>-12.4.0.0.16.tgz
The following table lists meta package files provided for this release.
Note
OS RPMs may need to be installed prior to software installation. Dependencies will be flagged during installation.
RPM Name | Description |
|---|---|
RHEL and SLES | |
cn5000_pkgs_cuda_meta-12_4_0_0-16.x86_64.rpm | CN5000 Meta Package containing all of the required CUDA RPMs |
cn5000_pkgs_non_gpu_meta-12_4_0_0-16.x86_64.rpm | CN5000 Meta Package containing all of the required RPMs |
cn5000_pkgs_rocm_meta-12_4_0_0-16.x86_64.rpm | CN5000 Meta Package containing all of the required ROCm RPMs |
Ubuntu | |
cn5000-pkgs-cuda-meta_12.4.0.0.16_amd64.deb | CN5000 Meta Package containing all of the required CUDA DEBs |
cn5000-pkgs-non-gpu-meta_12.4.0.0.16_amd64.deb | CN5000 Meta Package containing all of the required DEBs |
cn5000-pkgs-rocm-meta_12.4.0.0.16_amd64.deb | CN5000 Meta Package containing all of the required ROCm DEBs |
Refer to Appendix A, Release Package Manifest for the list of RPM and DEB files provided in this release.
System Requirements
This section lists the compatible operating systems and supported hardware.
Operating Systems
This release of the CN5000 OPX Software supports the operating systems listed in the following table.
Operating System | Base Kernel Version |
|---|---|
RHEL/Rocky Linux 9.4 | 5.14.0-427.13.1el9_4.x86_64 |
RHEL/Rocky Linux 9.6 | 5.14.0-570.12.1.el9_6.x86_64 |
RHEL/Rocky Linux 9.7 | 5.14.0-611.5.1.el9_7.x86_64 |
RHEL/Rocky Linux 9.8 | 5.14.0-687.5.3.el9_8.x86_64 |
RHEL/Rocky Linux 10.1 | 6.12.0-124.8.1.el10_1.x86_64 |
RHEL/Rocky Linux 10.2 | 6.12.0_211.7.3.el10_2.x86_64 |
SLES 15 SP7 | 6.4.0-150700.51-default |
SLES 16 | 6.12.0_160000.5_default |
Ubuntu 24.04 LTS | 6.8.0 |
Ubuntu 26.04 LTS | 7.0.0 |
Supported GPU Software
This release supports the GPU Software versions listed in the following table.
Note
The libfabric source rpm can be rebuilt to work with other ROCm and CUDA versions. Contact support@cornelis.com for assistance if needed.
Operating System | CUDA Version | ROCm Version |
|---|---|---|
RHEL/Rocky Linux 9.4 | 13.1 | 6.2.0 |
RHEL/Rocky Linux 9.6 | 12.9 | 6.4.2 |
RHEL/Rocky Linux 9.7 | 13.1 | 7.1.1 |
RHEL/Rocky Linux 9.8 | 13.3 Update 1 | 7.14 |
RHEL/Rocky Linux 10.1 | 13.1 | 7.2.0 |
RHEL/Rocky Linux 10.2 | 13.3 Update 1 | 7.14 |
SLES 15 SP7 | 13.0 | 6.4.3 |
SLES 16 | 13.2 | 7.14 |
Ubuntu 24.04 LTS | 12.9 | 6.1.2 |
Ubuntu 26.04 LTS | 13.3 | 7.14 |
Supported Hardware
The following tables list the hardware supported in this release.
Hardware | Description |
|---|---|
CN5000 Switch | |
CN5000 Switch, 48-Port, CN5SWE48G2AF | 240/277 VAC in, Dual Power Supply, Air-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2AP | 240/277 VAC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48G2WF | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2WP | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2AP | 48 VDC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2WP | 48 VDC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Director Class Switch and Components | |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAB | 240/277 VAC in, Air-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAC | 240/277 VAC in, Air-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48A | 48-Port, Air-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01A | Air-Cooled |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWB | 240/277 VAC in, Liquid-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWC | 240/277 VAC in, Liquid-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48W | 48-Port, Liquid-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01W | Liquid-Cooled |
Hardware | Description |
|---|---|
CN5000 SuperNIC, CN5HFA2D5ALS | Dual Port, QSFP-DD, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5ALS | Single Port, QSFP, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5NLS | Single Port, QSFP, x16 PCIe Gen 5, Conduction-Cooled, Low Profile, Single |
Hardware | Description |
|---|---|
CPUs | |
4th Gen AMD EPYC Processor | Genoa Zen 4 CPU-based servers |
5th Gen AMD EPYC Processor | Turin Zen 5 CPU-based servers |
4th Generation Intel Xeon Scalable Processor | Sapphire Rapids CPU-based servers |
5th Generation Intel Xeon Scalable Processor | Emerald Rapids CPU-based servers |
GPUs | |
AMD Instinct MI Series GPU | AMD Instinct MI300X and MI200 series Graphic Processing Units |
NVIDIA GPUs | NVIDIA Tesla V100 and later |
Installation Requirements
Refer to the CN5000 Fabric Installation Guide for related software requirements and complete installation procedures.
Important
Upgrades from pre-12.4 releases require a full uninstall of the existing CN5000 OPX Software (including removing all residual packages from hosts and repositories) prior to installing version 12.4 or later.
To uninstall the CN5000 OPX Software, refer to the CN5000 Maintenance and Troubleshooting Guide, Remove OPX Software from a Host.
To install the CN5000 OPX Software, refer to the CN5000 Fabric Installation Guide, Install the OPX Software.
Best Practices
To obtain the most recent functional and security updates, Cornelis recommends that you download and install the latest versions of the CN5000 Omni-Path software and firmware. Software and Documentation are found in the Cornelis Customer Center.
To ensure optimal performance in your CN5000 fabric, it is important to review the Cornelis performance tuning recommendations in the CN5000 Performance Tuning Guide.
Issues
This section lists the resolved and open issues.
Resolved Issues
The following table lists issues that are resolved in this release.
ID | Description | Resolved in Release |
|---|---|---|
STL-79194 | Transfers using GPU (ROCm) buffers over the OPX Provider may abort with | 12.4.0 |
STL-78983 | Running certain verbs tests, such as | 12.4.0 |
STL-77873 | Megatron-LM training (Llama3-8B) hangs on multi-node configurations when using | 12.4.0 |
STL-76144 | Setting the link speed policy to 100G in the opafm.xml file results in the following Fabric Manager error: Invalid Value for Link Speed Policy: 100G | 12.4.0 |
STL-75362 | When using the TCP provider of libfabric, some MPI applications may perform poorly or hang when launched with 1 process per core. This has been observed in benchmarks such as OSU Congestion, OSU Collectives, and IMB P2P. | 12.4.0 |
STL-74933 | Entries of the form | 12.4.0 |
STL-72573 | Hangs and errors have been seen in the OSU alltoall collective test when using the OPX Provider to libfabric with ROCm. | 12.4.0 |
STL-72423 | Some legacy Omni-Path host utilities have been deprecated for CN5000 but are still supported for OPA100. | 12.4.0 |
STL-75031 | MPI RMA benchmarks may produce an SDMA error (bad address) when using the OPX libfabric provider and environment variable FI_OPX_MIXED_NETWORK=0. | 12.4.0 |
Open Issues
The following tables list the open issues for this release.
ID | Description | Workaround |
|---|---|---|
STL-79912 | NCCL collectives may timeout or hang when running with non-NVLink GPU pairs on the same node. | Set NCCL_CUMEM_ENABLE=0. |
STL-79864 | When MPS is set to 256 before loading the hfi1 kernel module, a kernel halt condition may occur. | Set Refer to the CN5000 Performance Tuning Guide for more details. |
STL-79845 | When | IPoIB HFI Service (HFISVC) transmit mode requires that hfi1 be loaded before ib_ipoib. Refer to the CN5000 Performance Tuning Guide for the required load order and how to verify it. |
STL-79799 | Unexpected system fault and reboot may occur while running traffic with | Operating with Refer to the CN5000 Performance Tuning Guide or contact Cornelis Technical Support for help with configurations. |
STL-79771 | Installing the Ubuntu distribution perftest package attempts to uninstall OPX Software due to package conflicts. | Build and run perftest from source using the upstream repository: Perftest (GitHub). |
STL-79587 | In distro Truescale drivers ( | Blacklist |
STL-79559 | When running RCCL over its built-in verbs transport (NCCL_NET=IB), RCCL uses only two SuperNICs per node for inter-node communication, regardless of how many are installed. Additional SuperNICs are initialized but transmit no traffic, limiting collective communication bandwidth. NOTE: This is a RCCL defect (ROCm/rocm-systems#11138). | Perform one of the following:
|
STL-79524 | In certain Linux distributions, the default DHCP service does not support InfiniBand or IP over InfiniBand (IPoIB) interfaces. | Contact your Linux distribution vendor for approved alternative DHCP packages or configuration workarounds for IPoIB interfaces. |
STL-79445 | Five-minute timeouts may occur in BeeGFS when RDMA connections are enabled ( NOTE: A patch is pending per Beegfs (GitHub). | Set |
STL-79193 | On SLES distros, the hfi1 driver version may appear incorrect. | To ensure the correct driver is running, use the |
STL-78398 | On nodes running Ubuntu 24.04 with OPX Software installed, the The errors persist indefinitely and can consume excessive CPU resources until the | Stop the
NOTE: Disabling |
STL-78397 | On Ubuntu 24.04, the opafm service may intermittently fail to start at boot, reporting: ibwarn: get_abi_version: can't read ABI version from /sys/class/infiniband_mad/abi_version Invalid config detected! Couldn't find device for instance 0! Couldn't find device for instance 0! This is caused by a boot-time race condition. | After a reboot, perform the following:
|
STL-78250 | A Verbs SEND operation using PIO may fail to detect that send credits have been returned. This causes the send path to get stuck, preventing further send operations even though the hardware is ready. | Set |
STL-78089 | ROCm HIP pointer queries may cause a process hang during teardown. This is a known ROCm issue related to OpenMP target allocations recorded in https://github.com/ROCm/rocm-systems/issues/7099. | Use HIP-managed allocations (e.g., hipMalloc()) instead of OpenMP target allocations for buffers used with OPX GPU-direct/HMEM operations. Avoid mixing OpenMP target allocations with HIP pointer introspection until the ROCm issue is resolved upstream. |
STL-77891 | When installing or uninstalling the opxs-kernel-updates-kmp-default package on SLES 16, warnings appear stating that the RPM's post-install or post-uninstall scriptlet failed. | These warnings can be ignored. |
STL-77578 | CableInfo errors encountered when using the | Use LID-routed packets to get cable information. |
STL-77479 | Running opatop may report over line rate. | None. |
STL-77171 | On SLES, building the kernel driver RPMs may fail when multiple kernels are installed. | Perform the following:
|
STL-76907 | The following Lustre Error may occur: Write request failed with -14 NOTE: This is a general defect that affects all Lustre 2.17.0 stacks (refer to Lustre-Release Issue #16 | Avoid this issue by disabling hybrid IO functionality using the following command on the MGS server: lctl set_param -P llite.*.hybrid_io=0 |
STL-76435 |
Invalid Attribute or Attribute Modifier NOTE: The PMA response has a maximum payload size that limits the number of ports that can be returned in a single query. | Split the port select mask ( For example, on a 48-port switch, query ports in groups of 20 or fewer:
|
STL-76348 | Running | None. |
STL-76323 | SuperNICs may intermittently fail to enumerate on the PCIe bus or initialize after a cold boot or power cycle. In affected systems, one or more SuperNICs may be absent from the OS, preventing the node from participating in the fabric until the device is successfully detected and initialized. | Power cycle the server. |
STL-76313 | Kernel messages such as the following may be seen: CPORT request wait interrupted Dropping incoming CPORT message | Set the hfi1 module parameter |
STL-75568 | Performance test failures may occur when running ib_send_bw and ib_read_bw with the | Do not use the |
STL-75484 | Running | To drop and reinitialize a link, use the Alternately, if |
STL-74968 | Updating the Fabric Manager using DNF may not succeed even though an update is available. | Perform the following:
|
STL-74477 | Building opxs-kernel-updates from the src.rpm file fails with | Use an environment variable to allow the header file to be detected and used in the build: NVIDIA_DIR=$(ls -d /usr/src/nvidia-* | head -1)
ln -s ${NVIDIA_DIR}/nvidia /usr/src/kernels/5.14.0-503.14.1.el9_5.x86_64/include/nvidiaNote that the exact directory required for the symbolic link will depend on your kernel version. |
STL-74025 | When using IPoIB, SuperNICs do not change MTU or join MC groups automatically. | Use the |
STL-73738 | Reloading the ipoib kernel module without also reloading the hfi1 module may cause FM errors. | To avoid this, always reload the hfi1 module along with the ipoib module. |
STL-73714 | Performing an | Counter values in this scenario should be ignored. |
STL-73713 | In a fabric with no data traffic, the Xmit Time Congestion port counter will increment. | No workaround. |
STL-73669 | Executing | The message may be ignored. |
STL-73215 | When running | Use |
STL-73160 | The comments in the Adaptive Routing section of the opafm.xml file do not explain which settings are required for MGAR or for FGAR. | Currently the only field related to FGAR is
All other fields are related to legacy MGAR and will be ignored if |
STL-73140 | The following CN5000 commands do not work as expected:
| Note the following:
|
STL-72583 | In some cases the dmesg log may contain a message stating:
| This is cosmetic and will not affect functionality. |
STL-72541 | Running the | These errors can be ignored. |
STL-72536 STL-72537 | CableInfo errors encountered when using the | Cable information reporting not currently supported. |
STL-72526 | The Fabric Manager system log port numbering is different from Switch CLI command port numbering. | For details, contact support@cornelis.com for technical advisory TA0061. |
STL-72420 | On some versions of RHEL 9.x, there is a known failure (rdmavt driver deadlock.) recorded in https://issues.redhat.com/browse/RHEL-83851. NOTE: Cornelis has not replicated this problem, but it is possible that customers may be affected. | No workaround. |
STL-72160 | After uninstalling the meta packages with a package manager, several Cornelis Networks packages remain. | Refer to the CN5000 Maintenance and Troubleshooting Guide, “Remove OPX Software from a Host” for removal of the remaining packages. |
STL-72028 | Hangs have been seen in the NCCL alltoall_perf test when using the OPX provider to libfabric. | No workaround. |
STL-71364 STL-72423 | Some legacy Omni-Path host utilities have been deprecated for CN5000 but are still supported for OPA100. | For a list of commands supported for CN5000, refer to the Man Pages or CN5000 Commands Guide. |
STL-70552 | Rebuilding Open MPI or mvapich2 with FastFabric utilities ( | These utilities are compatible only with the Intel ICC compiler. Rebuild Open MPI or mvapich2 using the ICC compiler, or rebuild manually. |
STL-67178 | After boot, the OPX Software hfi1-NVIDIA support is not available. | Review boot configuration to ensure that nvidia-driver will be available when hfi1 is loaded. |
STL-64974 | Failures have been observed when running the IMB-EXT "Window" benchmark using the OPX Provider and ppn greater than (num_user_contexts/2). | To run the IMB-EXT benchmark with the OPX Provider and higher PPN, reload the hfi1 module with an increased num_user_contexts value. For example, if the server has 40 physical cores and you want to run one IMB-EXT process per core, increase the number of hfi1 contexts to 80. See the CN5000 Performance Tuning Guide, “HFI1 Driver Module Parameters” for instructions. The benchmark can now be run with #contexts/2 = 40 PPN, one for each CPU core. |
Product Limitations
This release has the following limitations:
OPX Software releases 12.2.0 and 12.3.0 cannot be simultaneously deployed in an Omni-Path fabric with Bulk Transfer Service (BTS) enabled due to wire protocol differences introduced by recent performance optimizations.
If you plan to deploy in a hybrid fabric with OPA100 and CN5000 interoperating together, contact support@cornelis.com for guidance before deploying this release.
IPoIB connected mode and the verbs IPoIB datapath with Accelerated IP (AIP) disabled have been deprecated. Both remain functional in this release but are no longer recommended, may exhibit known issues, and will be removed in a future release.
The supported configurations are IPoIB datagram mode with AIP enabled (default), and the AIP HFISVC transmit mode (ipoib_tx_mode=hfisvc).
When running MVAPICH3 with the OPX provider of libfabric, a
*** buffer overflow detected ***error may cause the job to terminate. This issue has been observed when running with a high number of processes, particularly when using 1 process per core (that is, the maximum number of processes the system can support). A workaround is to set the environment variableMV2_ENABLE_AFFINITY=0to disable CPU affinity.Queries to single port adapters will reflect that there are two ports with the first port always showing as offline.
Running of MPI jobs across both CN5000 and OPA100 components in hybrid fabrics (fabrics where CN5000 and OPA100 are connected) is not presently supported.
In the opafm.xml file, the default HFI port for fm0 must be set as follows for proper operation:
For Version I SuperNIC boards:
<Name>fm0</Name> <Hfi>1</Hfi> <Port>2</Port>For Version II SuperNIC boards:
<Name>fm0</Name> <Hfi>1</Hfi> <Port>1</Port>To determine which generation board you have, refer to the Prerequisites under CN5000 Maintenance and Troubleshooting Guide, "Replace the SuperNIC".
Non-default
MinShareVLMemandDedicatedVLMemvalues are not supported. Only use default values.Some distros versions may ship with ib_qib driver enabled. This driver is incompatible with the OPX Software and may result in errors such as
disagrees about version of symbolin logs. Setblacklist ib_qib.During link bring up on a mixed OPA100/CN5000/CN6000 fabric the FM log may show "Mismatch/Unable to set SCVL_t Map" warnings and link bounces may be observed as the fabric comes up. These messages and link bounces are expected on mixed fabrics and do not indicate a fault.
Enabling vFabrics with QoS results in Neighbor Mismatch/Unable to set SCVL_nt Map and Failed to init SL Maps in the log, and port bounces. There is no workaround. Port bounces are part of the standard recovery mechanism. These messages should only occur once and only when there is a change in the SCVL maps.
opainfo displays a single port adapter as a dual port adapter. No workaround. This is informational.
Ubuntu server fails to boot with more than one CN5000 Omni-Path installed. Ubuntu platforms cannot host multiple SuperNICs.
MVAPICH-Plus 4.1 for GPU is not supported.
The sph_exa application in SpecHPC hangs when using Open MPI. Set the following when running Open MPI:
-mca topo ^treematch
ibtracertis not supported in the Omni-Path environment. As an alternative, useopareport -o linksoropaextractlink.
Preface
This document provides an overview of the changes introduced in this release. References to more detailed information are provided where necessary. The information contained in this document is intended as supplemental information only; it should be used in conjunction with the documentation provided for each component.
Software License Agreement
The software is provided under license agreements and may contain third-party software under separate third-party licensing. Refer to the license files provided with the software for specific details.
If You Need Help
Technical support for all Cornelis products is available 24 hours a day, 365 days a year.
For additional details:
Visit the Cornelis Support page at http://www.cornelisnetworks.com/support
Contact email: support@cornelisnetworks.com
Release Compatibility
This release is backward compatible with the most recent minor release version. For example, Release 12.N is backward compatible with Release 12.N-1 and Release 12.N-1.x.
New in This Release
The following features are new in this release:
Support for new OSes: RHEL/Rocky Linux 10.2 and Ubuntu 26.04 LTS
Maintenance Updates
Release Items
The following software package is available for this release:
CN5000_OPXSoftware-<DISTRO>-12.3.0.1.7.tgz (for all OSes except SLES 16)
CN5000_OPXSoftware-SLES16-12.3.0.2.1.tgz (for SLES 16)
The following table lists meta package files provided for this release.
Note
OS RPMs may need to be installed prior to software installation. Dependencies will be flagged during installation.
RPM Name | Description |
|---|---|
RHEL and SLES (All OSes except SLES 16) | |
cn5000_pkgs_cuda_meta-12_3_0_1-7.x86_64.rpm | CN5000 Meta Package containing all of the required CUDA RPMs |
cn5000_pkgs_non_gpu_meta-12_3_0_1-7.x86_64.rpm | CN5000 Meta Package containing all of the required RPMs |
cn5000_pkgs_rocm_meta-12_3_0_1-7.x86_64.rpm | CN5000 Meta Package containing all of the required ROCm RPMs |
SLES 16 | |
cn5000_pkgs_cuda_meta-12_3_0_2-1.x86_64.rpm | CN5000 Meta Package containing all of the required CUDA RPMs |
cn5000_pkgs_non_gpu_meta-12_3_0_2-1.x86_64.rpm | CN5000 Meta Package containing all of the required RPMs |
cn5000_pkgs_rocm_meta-12_3_0_2-1.x86_64.rpm | CN5000 Meta Package containing all of the required ROCm RPMs |
Ubuntu | |
cn5000-pkgs-cuda-meta_12.3.0.1.7_amd64.deb | CN5000 Meta Package containing all of the required CUDA DEBs |
cn5000-pkgs-non-gpu-meta_12.3.0.1.7_amd64.deb | CN5000 Meta Package containing all of the required DEBs |
cn5000-pkgs-rocm-meta_12.3.0.1.7_amd64.deb | CN5000 Meta Package containing all of the required ROCm DEBs |
Refer to Appendix B, Release Package Manifest for the list of RPM and DEB files provided in this release.
System Requirements
This section lists the compatible operating systems and supported hardware.
Operating Systems
This release of the CN5000 OPX Software supports the operating systems listed in the following table.
Operating System | Base Kernel Version |
|---|---|
RHEL/Rocky Linux 9.4 | 5.14.0-427.13.1el9_4.x86_64 |
RHEL/Rocky Linux 9.6 | 5.14.0-570.12.1.el9_6.x86_64 |
RHEL/Rocky Linux 9.7 | 5.14.0-611.5.1.el9_7.x86_64 |
RHEL/Rocky Linux 9.8 | 5.14.0-687.5.3.el9_8.x86_64 |
RHEL/Rocky Linux 10.1 | 6.12.0-124.8.1.el10_1.x86_64 |
RHEL/Rocky Linux 10.2 | 6.12.0_211.7.3.el10_2.x86_64 |
SLES 15 SP7 | 6.4.0-150700.51-default |
SLES 16 | 6.12.0_160000.5_default |
Ubuntu 24.04 LTS | 6.8.0 |
Ubuntu 26.04 LTS | 7.0.0 |
Supported GPU Software
This release supports the GPU Software versions listed in the following table.
Note
The libfabric source rpm can be rebuilt to work with other ROCm and CUDA versions. Contact support@cornelis.com for assistance if needed.
Operating System | CUDA Version | ROCm Version |
|---|---|---|
RHEL/Rocky Linux 9.4 | 13.1 | 6.2.0 |
RHEL/Rocky Linux 9.6 | 12.9 | 6.4.2 |
RHEL/Rocky Linux 9.7 | 13.1 | 7.1.1 |
RHEL/Rocky Linux 9.8 | 13.3 Update 1 | 7.14 |
RHEL/Rocky Linux 10.1 | 13.1 | 7.2.0 |
RHEL/Rocky Linux 10.2 | 13.3 Update 1 | 7.14 |
SLES 15 SP7 | 13.0 | 6.4.3 |
SLES 16 | 13.2 | 7.14 |
Ubuntu 24.04 LTS | 12.9 | 6.1.2 |
Ubuntu 26.04 LTS | 13.3 | 7.14 |
Supported Hardware
The following tables list the hardware supported in this release.
Hardware | Description |
|---|---|
CN5000 Switch | |
CN5000 Switch, 48-Port, CN5SWE48G2AF | 240/277 VAC in, Dual Power Supply, Air-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2AP | 240/277 VAC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48G2WF | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2WP | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2AP | 48 VDC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2WP | 48 VDC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Director Class Switch and Components | |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAB | 240/277 VAC in, Air-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAC | 240/277 VAC in, Air-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48A | 48-Port, Air-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01A | Air-Cooled |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWB | 240/277 VAC in, Liquid-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWC | 240/277 VAC in, Liquid-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48W | 48-Port, Liquid-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01W | Liquid-Cooled |
Hardware | Description |
|---|---|
CN5000 SuperNIC, CN5HFA2D5ALS | Dual Port, QSFP-DD, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5ALS | Single Port, QSFP, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5NLS | Single Port, QSFP, x16 PCIe Gen 5, Conduction-Cooled, Low Profile, Single |
Hardware | Description |
|---|---|
CPUs | |
4th Gen AMD EPYC Processor | Genoa Zen 4 CPU-based servers |
5th Gen AMD EPYC Processor | Turin Zen 5 CPU-based servers |
4th Generation Intel Xeon Scalable Processor | Sapphire Rapids CPU-based servers |
5th Generation Intel Xeon Scalable Processor | Emerald Rapids CPU-based servers |
GPUs | |
AMD Instinct MI Series GPU | AMD Instinct MI300X and MI200 series Graphic Processing Units |
NVIDIA GPUs | NVIDIA Tesla V100 and later |
Installation Requirements
Refer to the CN5000 Fabric Installation Guide for related software requirements and complete installation procedures.
Best Practices
To obtain the most recent functional and security updates, Cornelis recommends that you download and install the latest versions of the CN5000 Omni-Path software and firmware. Software and Documentation are found in the Cornelis Customer Center.
To ensure optimal performance in your CN5000 fabric, it is important to review the Cornelis performance tuning recommendations in the CN5000 Performance Tuning Guide.
Issues
This section lists the resolved and open issues.
Resolved Issues
The following table lists issues that are resolved in this release.
ID | Description | Resolved in Release |
|---|---|---|
STL-79549 | Installing OPX Software 12.3 replaces the distro | 12.3.0 |
STL-77956 | GPU applications hang with Open MPI 5.0.8 and earlier | 12.3.0 |
STL-76942 | Lustre errors occur with Bulk Transfer Service (BTS) enabled (hfi1 driver parameter | 12.3.0 |
STL-76644 | MPI RMA benchmarks may produce an SDMA error (bad address) when using the OPX libfabric provider and environment variable FI_OPX_MIXED_NETWORK=0. | 12.3.0 |
STL-76131 | When using SR-IOV, the dmesg log in the VMs may occasionally show the following warning message: memcpy: detected field-spanning write | 12.3.0 |
STL-75535 | GADGET4 MPI application hangs with OPX Provider. | 12.3.0 |
STL-74679 | While running IPoIB in Connected mode, application hangs have been observed. | 12.3.0 |
STL-74625 | When using both ports of a dual-port SuperNIC, the | 12.3.0 |
STL-73531 | Configuring more than two data VLs is not currently supported. Doing so may lead to incorrect mappings of SC to VL. Configured data VL limitation added to CN5000 Commands Guide, | 12.3.0 |
STL-72673 | OS-release file captured by opacapture is empty. | 12.3.0 |
Open Issues
The following tables list the open issues for this release.
ID | Description | Workaround |
|---|---|---|
STL-79445 | When the hfi1 driver is loaded with the Bulk Transfer Service (BTS) module parameter enabled ( Communication error in SENDDATA stage | Perform one of the following:
|
STL-79194 | Transfers using GPU (ROCm) buffers over the OPX Provider may abort with | Set the following environment variables to prevent the failure path:
|
STL-79193 | On SLES distros, the hfi1 driver version may appear incorrect. | To ensure the correct driver is running, use the |
STL-78983 | Running certain verbs tests, such as | Restrict memory buffer sizes to less than 4GB. |
STL-78397 | On CN5000 nodes running Ubuntu 24.04 with OPX Software installed, the The errors persist indefinitely and can consume excessive CPU resources until the | Stop the
NOTE: Disabling |
STL-78250 | A Verbs SEND operation using PIO may fail to detect that send credits have been returned. This causes the send path to get stuck, preventing further send operations even though the hardware is ready. | Set |
STL-78089 | ROCm HIP pointer queries may cause a process hang during teardown. This is a known ROCm issue related to OpenMP target allocations recorded in https://github.com/ROCm/rocm-systems/issues/7099. | Use HIP-managed allocations (e.g., hipMalloc()) instead of OpenMP target allocations for buffers used with OPX GPU-direct/HMEM operations. Avoid mixing OpenMP target allocations with HIP pointer introspection until the ROCm issue is resolved upstream. |
STL-77891 | When installing or uninstalling the opxs-kernel-updates-kmp-default package on SLES 16, warnings appear stating that the RPM's post-install or post-uninstall scriptlet failed. | These warnings can be ignored. |
STL-77873 | Megatron-LM training (Llama3-8B) hangs on multi-node configurations when using | Use |
STL-77578 | CableInfo errors encountered when using the | Use LID-routed packets to get cable information. |
STL-77479 | Running opatop may report over line rate. | None. |
STL-77171 | On SLES, building the kernel driver RPMs may fail when multiple kernels are installed. | Perform the following:
|
STL-76907 | The following Lustre Error may occur: Write request failed with -14 NOTE: This is a general defect that affects all Lustre 2.17.0 stacks (refer to Lustre-Release Issue #16 | Avoid this issue by disabling hybrid IO functionality using the following command on the MGS server: lctl set_param -P llite.*.hybrid_io=0 |
STL-76435 |
Invalid Attribute or Attribute Modifier NOTE: The PMA response has a maximum payload size that limits the number of ports that can be returned in a single query. | Split the port select mask ( For example, on a 48-port switch, query ports in groups of 20 or fewer:
|
STL-76348 | Running | None. |
STL-76323 | SuperNICs may intermittently fail to enumerate on the PCIe bus or initialize after a cold boot or power cycle. In affected systems, one or more SuperNICs may be absent from the OS, preventing the node from participating in the fabric until the device is successfully detected and initialized. | Power cycle the server. |
STL-76313 | Kernel messages such as the following may be seen: CPORT request wait interrupted Dropping incoming CPORT message | Set the hfi1 module parameter |
STL-76144 | Setting the link speed policy to 100G in the opafm.xml file results in the following Fabric Manager error: Invalid Value for Link Speed Policy: 100G | Set the link speed using the Switch CLI command |
STL-75568 | Performance test failures may occur when running ib_send_bw and ib_read_bw with the | Do not use the |
STL-75526 | After installing the OPX Software package on Ubuntu, the opafm service is enabled by default. | Manually disable the opafm service by default. |
STL-75484 | Running | To drop and reinitialize a link, use the Alternately, if |
STL-75395 | When | Disable |
STL-75362 | When using the TCP provider of libfabric, some MPI applications may perform poorly or hang when launched with 1 process per core. This has been observed in benchmarks such as OSU Congestion, OSU Collectives, and IMB P2P. | For best results, users should use the OPX provider whenever available. OPX can be explicitly selected by setting the environment variable, |
STL-75322 | Upon reverting from 12.0.3 to a previous RHEL/Rocky release certain packages may not be removed. | Use the following command to remove the remaining packages: dnf remove ibacm infiniband-diags libfabric libhfi1verbs libibumad libibverbs libpsm2 librdmacm librdmacm-utils mpi-selector opa-basic-tools opa-fastfabric opa-fm opa-libopamgt rdma-core rdma-core-devel srp_daemon |
STL-75031 | MPI RMA benchmarks may produce an SDMA error (bad address) when using the OPX libfabric provider and environment variable FI_OPX_MIXED_NETWORK=0. | FI_OPX_MIXED_NETWORK is deprecated and should no longer be set. Contact support@cornelis.com. |
STL-74968 | Updating the Fabric Manager using DNF may not succeed even though an update is available. | Perform the following:
|
STL-74933 | Entries of the form | These messages can be ignored. |
STL-74477 | Building opxs-kernel-updates from the src.rpm file fails with | Use an environment variable to allow the header file to be detected and used in the build: NVIDIA_DIR=$(ls -d /usr/src/nvidia-* | head -1)
ln -s ${NVIDIA_DIR}/nvidia /usr/src/kernels/5.14.0-503.14.1.el9_5.x86_64/include/nvidiaNote that the exact directory required for the symbolic link will depend on your kernel version. |
STL-74025 | When using IPoIB on CN5000, SuperNICs do not change MTU or join MC groups automatically. | Use the |
STL-73928 | HFI links bounce and the SM reports mapping warnings following the second FM restart. | No Workaround. Links that bounce recover and the fabric stabilizes. |
STL-73738 | Reloading the ipoib kernel module without also reloading the hfi1 module may cause FM errors. | To avoid this, always reload the hfi1 module along with the ipoib module. |
STL-73716 | The | Ignore the congestion flag. |
STL-73714 | Performing an | Counter values in this scenario should be ignored. |
STL-73713 | In a fabric with no data traffic, the Xmit Time Congestion port counter will increment. | No workaround. |
STL-73669 | Executing | The message may be ignored. |
STL-73215 | When running | Use |
STL-73160 | The comments in the Adaptive Routing section of the opafm.xml file do not explain which settings are required for MGAR or for FGAR. | Currently the only field related to FGAR is
All other fields are related to legacy MGAR and will be ignored if |
STL-73140 | The following CN5000 commands do not work as expected:
| Note the following:
|
STL-72583 | In some cases the dmesg log may contain a message stating:
| This is cosmetic and will not affect functionality. |
STL-72573 | Hangs and errors have been seen in the OSU alltoall collective test when using the OPX Provider to libfabric with ROCm. | No workaround. |
STL-72541 | Running the | These errors can be ignored. |
STL-72536 STL-72537 | CableInfo errors encountered when using the | Cable information reporting not currently supported. |
STL-72526 | The Fabric Manager system log port numbering is different from Switch CLI command port numbering. | For details, contact support@cornelis.com for technical advisory TA0061. |
STL-72420 | On some versions of RHEL 9.x, there is a known failure (rdmavt driver deadlock.) recorded in https://issues.redhat.com/browse/RHEL-83851. NOTE: Cornelis has not replicated this problem, but it is possible that customers may be affected. | No workaround. |
STL-72160 | After uninstalling the meta packages with a package manager, several Cornelis Networks packages remain. | Refer to the CN5000 Maintenance and Troubleshooting Guide, “Remove OPX Software from a Host” for removal of the remaining packages. |
STL-71364 STL-72423 | Some legacy Omni-Path host utilities have been deprecated for CN5000 but are still supported for OPA100. | For a list of commands supported for CN5000, refer to the Man Pages or CN5000 Commands Guide. |
STL-67178 | After boot, the OPX Software hfi1-NVIDIA support is not available. | Review boot configuration to ensure that nvidia-driver will be available when hfi1 is loaded. |
Product Limitations
This release has the following limitations:
OPX Software releases 12.2.0 and 12.3.0 cannot be simultaneously deployed in an Omni-Path fabric with Bulk Transfer Service (BTS) enabled due to wire protocol differences introduced by recent performance optimizations.
Large GPU-Direct messages (∼1 GB) over OPX on AMD MI300X may trigger Bulk Transport Services (BTS) completion-queue errors, causing fabric errors, MPI internal errors, or RCCL errors.
If you plan to deploy in a hybrid fabric with OPA100 and CN5000 interoperating together, contact support@cornelis.com for guidance before deploying this release.
When running MVAPICH3 with the OPX provider of libfabric, a
*** buffer overflow detected ***error may cause the job to terminate. This issue has been observed when running with a high number of processes, particularly when using 1 process per core (that is, the maximum number of processes the system can support). A workaround is to set the environment variableMV2_ENABLE_AFFINITY=0to disable CPU affinity.Queries to single port adapters will reflect that there are two ports with the first port always showing as offline.
Running of MPI jobs across both CN5000 and OPA100 components in hybrid fabrics (fabrics where CN5000 and OPA100 are connected) is not presently supported.
In the opafm.xml file, the default HFI port for fm0 must be set as follows for proper operation:
For Version I SuperNIC boards:
<Name>fm0</Name> <Hfi>1</Hfi> <Port>2</Port>For Version II SuperNIC boards:
<Name>fm0</Name> <Hfi>1</Hfi> <Port>1</Port>To determine which generation board you have, refer to the Prerequisites under CN5000 Maintenance and Troubleshooting Guide, "Replace the SuperNIC".
Non-default
MinShareVLMemandDedicatedVLMemvalues are not supported. Only use default values.Some distros versions may ship with ib_qib driver enabled. This driver is incompatible with the CN5000 OPX Software and may result in errors such as
disagrees about version of symbolin logs. Setblacklist ib_qib.During link bring up on a mixed OPA100/CN5000 fabric the FM log may show "Mismatch/Unable to set SCVL_t Map" warnings and link bounces may be observed as the fabric comes up. These messages and link bounces are expected on mixed fabrics and do not indicate a fault.
Enabling vFabrics with QoS results in Neighbor Mismatch/Unable to set SCVL_nt Map and Failed to init SL Maps in the log, and port bounces. There is no workaround. Port bounces are part of the standard recovery mechanism. These messages should only occur once and only when there is a change in the SCVL maps.
opainfo displays a single port adapter as a dual port adapter. No workaround. This is informational.
Ubuntu server fails to boot with more than one CN5000 SuperNIC installed. Ubuntu platforms cannot host multiple SuperNICs.
MVAPICH-Plus 4.1 for GPU is not supported.
The sph_exa application in SpecHPC hangs when using Open MPI. Set the following when running Open MPI:
-mca topo ^treematch
ibtracertis not supported in the Omni-Path environment. As an alternative, useopareport -o linksoropaextractlink.
Preface
This document provides an overview of the changes introduced in this release. References to more detailed information are provided where necessary. The information contained in this document is intended as supplemental information only; it should be used in conjunction with the documentation provided for each component.
Software License Agreement
The software is provided under license agreements and may contain third-party software under separate third-party licensing. Refer to the license files provided with the software for specific details.
If You Need Help
Technical support for all Cornelis products is available 24 hours a day, 365 days a year.
For additional details:
Visit the Cornelis Support page at http://www.cornelisnetworks.com/support
Contact email: support@cornelisnetworks.com
Release Compatibility
This release is backward compatible with the most recent minor release version. For example, Release 12.N is backward compatible with Release 12.N-1 and Release 12.N-1.x.
New in This Release
The following features are new in this release:
Support for new OSes: RHEL/Rocky Linux 9.8, 10.1 and SLES 16.0
Support for In-Band Management
Maintenance Updates
Release Items
The following software package is available for this release:
CN5000_OPXSoftware-<DISTRO>-12.2.0.0.54.tgz
Note
OS RPMs may need to be installed prior to software installation. Dependencies will be flagged during installation.
The following table lists meta package files provided for this release.
RPM Name | Description |
|---|---|
RHEL and SLES | |
cn5000_pkgs_cuda_meta-12_2_0_0-54.x86_64.rpm | CN5000 Meta Package containing all of the required CUDA RPMs |
cn5000_pkgs_non_gpu_meta-12_2_0_0-54.x86_64.rpm | CN5000 Meta Package containing all of the required RPMs |
cn5000_pkgs_rocm_meta-12_2_0_0-54.x86_64.rpm | CN5000 Meta Package containing all of the required ROCm RPMs |
Ubuntu | |
cn5000-pkgs-cuda-meta_12.2.0.0.54-amd64.deb | CN5000 Meta Package containing all of the required CUDA DEBs |
cn5000-pkgs-non-gpu-meta_12.2.0.0.54-amd64.deb | CN5000 Meta Package containing all of the required DEBs |
cn5000-pkgs-rocm-meta_12.2.0.0.54-amd64.deb | CN5000 Meta Package containing all of the required ROCm DEBs |
Refer to Appendix C, Release Package Manifest for the list of RPM and DEB files provided in this release.
System Requirements
This section lists the compatible operating systems and supported hardware.
Operating Systems
This release of the CN5000 OPX Software supports the operating systems listed in the following table.
Operating System | Base Kernel Version |
|---|---|
RHEL/Rocky Linux 9.4 | 5.14.0-427.13.1el9_4.x86_64 |
RHEL/Rocky Linux 9.6 | 5.14.0-570.12.1.el9_6.x86_64 |
RHEL/Rocky Linux 9.7 | 5.14.0-611.5.1.el9_7.x86_64 |
RHEL/Rocky Linux 9.8 | 5.14.0-687.5.3.el9_8.x86_64 |
RHEL/Rocky Linux 10.0 | 6.12.0-55.9.1.el10_0.x86_64 |
RHEL/Rocky Linux 10.1 | 6.12.0-124.8.1.el10_1.x86_64 |
SLES 15 SP7 | 6.4.0-150700.53.22.1-default |
SLES 16 | 6.12.0_160000.5_default |
Ubuntu 24.04 LTS | 6.8.0-90-generic |
Supported GPU Software
This release supports the GPU Software versions listed in the following table.
Note
The libfabric source rpm can be rebuilt to work with other ROCm and CUDA versions. Contact support@cornelis.com for assistance if needed.
Operating System | ROCm Version | CUDA Version |
|---|---|---|
RHEL/Rocky Linux 9.4 | 6.2.0 | 13.1 |
RHEL/Rocky Linux 9.6 | 6.4.2 | 12.9 |
RHEL/Rocky Linux 9.7 | 7.1.1 | 13.1 |
RHEL/Rocky Linux 9.8 | Not supported | Not supported |
RHEL/Rocky Linux 10 | 7.1.1 | 13.1 |
RHEL/Rocky Linux 10.1 | 7.2.0 | 13.1 |
SLES 15 SP7 | 6.4.3 | 13.0 |
SLES 16 | Not supported | 13.2 |
Ubuntu 24.04 | 6.1.2 | 12.9 |
Supported Hardware
The following tables list the hardware supported in this release.
Hardware | Description |
|---|---|
CN5000 Switch | |
CN5000 Switch, 48-Port, CN5SWE48G2AF | 240/277 VAC in, Dual Power Supply, Air-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2AP | 240/277 VAC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48G2WF | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2WP | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2AP | 48 VDC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2WP | 48 VDC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Director Class Switch and Components | |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAB | 240/277 VAC in, Air-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAC | 240/277 VAC in, Air-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48A | 48-Port, Air-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01A | Air-Cooled |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWB | 240/277 VAC in, Liquid-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWC | 240/277 VAC in, Liquid-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48W | 48-Port, Liquid-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01W | Liquid-Cooled |
Hardware | Description |
|---|---|
CN5000 SuperNIC, CN5HFA2D5ALS | Dual Port, QSFP-DD, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5ALS | Single Port, QSFP, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5NLS | Single Port, QSFP, x16 PCIe Gen 5, Conduction-Cooled, Low Profile, Single |
Hardware | Description |
|---|---|
CPUs | |
4th Gen AMD EPYC Processor | Genoa Zen 4 CPU-based servers |
5th Gen AMD EPYC Processor | Turin Zen 5 CPU-based servers |
4th Generation Intel Xeon Scalable Processor | Sapphire Rapids CPU-based servers |
5th Generation Intel Xeon Scalable Processor | Emerald Rapids CPU-based servers |
GPUs | |
AMD Instinct MI Series GPU | AMD Instinct MI300X and MI200 series Graphic Processing Units |
NVIDIA GPUs | NVIDIA Tesla V100 and later |
Installation Requirements
Refer to the CN5000 Fabric Installation Guide for related software requirements and complete installation procedures.
Best Practices
To obtain the most recent functional and security updates, Cornelis recommends that you download and install the latest versions of the CN5000 Omni-Path software and firmware. Software and Documentation are found in the Cornelis Customer Center.
To ensure optimal performance in your CN5000 fabric, it is important to review the Cornelis performance tuning recommendations in the CN5000 Performance Tuning Guide.
Issues
This section lists the resolved and open issues.
Resolved Issues
The following table lists issues that are resolved in this release.
ID | Description | Resolved in Release |
|---|---|---|
STL-76137 | Open MPI traffic fails on SR-IOV Virtual Function devices. NOTE: SR-IOV Troubleshooting instructions have been added to the CN5000 Maintenance and Troubleshooting Guide. | 12.2.0 |
STL-74504 | Occasional drops in bandwidth observed during microbenchmark testing. For platform-specific tuning, refer to the CN5000 Performance Tuning Guide. | 12.2.0 |
Open Issues
The following tables list the open issues for this release.
ID | Description | Workaround |
|---|---|---|
STL-78250 | A Verbs SEND operation using PIO may fail to detect that send credits have been returned. This causes the send path to get stuck, preventing further send operations even though the hardware is ready. | Set |
STL-78089 | ROCm HIP pointer queries may cause a process hang during teardown. This is a known ROCm issue related to OpenMP target allocations recorded in https://github.com/ROCm/rocm-systems/issues/7099. | Use HIP-managed allocations (e.g., hipMalloc()) instead of OpenMP target allocations for buffers used with OPX GPU-direct/HMEM operations. Avoid mixing OpenMP target allocations with HIP pointer introspection until the ROCm issue is resolved upstream. |
STL-77956 | GPU applications hang with Open MPI 5.0.8 and earlier | Use Open MPI 5.0.9 or newer. |
STL-77891 | When installing or uninstalling the opxs-kernel-updates-kmp-default package on SLES 16, warnings appear stating that the RPM's post-install or post-uninstall scriptlet failed. | These warnings can be ignored. |
STL-77873 | Megatron-LM training (Llama3-8B) hangs on multi-node configurations when using | Use |
STL-77578 | CableInfo errors encountered when using the | Use LID-routed packets to get cable information. |
STL-76942 | Lustre errors occur with Bulk Transfer Service (BTS) enabled (hfi1 driver parameter | When mounting Lustre, BTS should not be enabled ( |
STL-76907 | The following Lustre Error may occur: Write request failed with -14 NOTE: This is a general defect that affects all Lustre 2.17.0 stacks (refer to Lustre-Release Issue #16 | Avoid this issue by disabling hybrid IO functionality using the following command on the MGS server: lctl set_param -P llite.*.hybrid_io=0 |
STL-76435 |
Invalid Attribute or Attribute Modifier NOTE: The PMA response has a maximum payload size that limits the number of ports that can be returned in a single query. | Split the port select mask ( For example, on a 48-port switch, query ports in groups of 20 or fewer:
|
STL-76348 | Running | None. |
STL-76323 | SuperNICs may intermittently fail to enumerate on the PCIe bus or initialize after a cold boot or power cycle. In affected systems, one or more SuperNICs may be absent from the OS, preventing the node from participating in the fabric until the device is successfully detected and initialized. | Power cycle the server. |
STL-76313 | Kernel messages such as the following may be seen: CPORT request wait interrupted Dropping incoming CPORT message | Set the hfi1 module parameter |
STL-76144 | Setting the link speed policy to 100G in the opafm.xml file results in the following Fabric Manager error: Invalid Value for Link Speed Policy: 100G | Set the link speed using the Switch CLI command |
STL-76131 | When using SR-IOV, the dmesg log in the VMs may occasionally show the following warning message: memcpy: detected field-spanning write | Do not run Omni-Path management tools, such as |
STL-75568 | Performance test failures may occur when running ib_send_bw and ib_read_bw with the | Do not use the |
STL-75535 | GADGET4 MPI application hangs with OPX Provider. | Contact support@cornelis.com. |
STL-75526 | After installing the OPX Software package on Ubuntu, the opafm service is enabled by default. | Manually disable the opafm service by default. |
STL-75484 | Running | To drop and reinitialize a link, use the Alternately, if |
STL-75395 | When | Disable |
STL-75362 | When using the TCP provider of libfabric, some MPI application may perform poorly or hang when launched with 1 process per core. This has been observed in benchmarks such as OSU Congestion, OSU Collectives, and IMB P2P. | For best results, users should use the OPX provider whenever available. OPX can be explicitly selected by setting the environment variable, |
STL-75322 | Upon reverting from 12.0.3 to a previous RHEL/Rocky release certain packages may not be removed. | Use the following command to remove the remaining packages: dnf remove ibacm infiniband-diags libfabric libhfi1verbs libibumad libibverbs libpsm2 librdmacm librdmacm-utils mpi-selector opa-basic-tools opa-fastfabric opa-fm opa-libopamgt rdma-core rdma-core-devel srp_daemon |
STL-75031 STL-76644 | MPI RMA benchmarks may produce an SDMA error (bad address) when using the OPX libfabric provider and environment variable FI_OPX_MIXED_NETWORK=0. | FI_OPX_MIXED_NETWORK is deprecated and should no longer be set. Contact support@cornelis.com. |
STL-74968 | Updating the Fabric Manager using DNF may not succeed even though an update is available. | Perform the following:
|
STL-74933 | Entries of the form | These messages can be ignored. |
STL-74679 | While running IPoIB in Connected mode, application hangs have been observed. | Configure IPoIB to Datagram mode and rerun the application. |
STL-74625 | When using both ports of a dual-port SuperNIC, the | Use |
STL-74477 | Building opxs-kernel-updates from the src.rpm file fails with | Use an environment variable to allow the header file to be detected and used in the build: NVIDIA_DIR=$(ls -d /usr/src/nvidia-* | head -1)
ln -s ${NVIDIA_DIR}/nvidia /usr/src/kernels/5.14.0-503.14.1.el9_5.x86_64/include/nvidiaNote that the exact directory required for the symbolic link will depend on your kernel version. |
STL-74025 | When using IPoIB on CN5000, SuperNICs do not change MTU or join MC groups automatically. | Use the |
STL-73928 | HFI links bounce and the SM reports mapping warnings following the second FM restart. | No Workaround. Links that bounce recover and the fabric stabilizes. |
STL-73738 | Reloading the ipoib kernel module without also reloading the hfi1 module may cause FM errors. | To avoid this, always reload the hfi1 module along with the ipoib module. |
STL-73716 | The | Ignore the congestion flag. |
STL-73714 | Performing an | Counter values in this scenario should be ignored. |
STL-73713 | In a fabric with no data traffic, the Xmit Time Congestion port counter will increment. | No workaround. |
STL-73669 | Executing | The message may be ignored. |
STL-73531 | Configuring more than two data VLs is not currently supported. Doing so may lead to incorrect mappings of SC to VL. | Limit the number of configured data VLs to two. |
STL-73215 | When running | Use |
STL-73160 | The comments in the Adaptive Routing section of the opafm.xml file do not explain which settings are required for MGAR or for FGAR. | Currently the only field related to FGAR is
All other fields are related to legacy MGAR and will be ignored if |
STL-73140 | The following CN5000 commands do not work as expected:
| Note the following:
|
STL-72673 | OS-release file captured by opacapture is empty. | Use |
STL-72583 | In some cases the dmesg log may contain a message stating:
| This is cosmetic and will not affect functionality. |
STL-72573 | Hangs and errors have been seen in the OSU alltoall collective test when using the OPX Provider to libfabric with ROCm. | No workaround. |
STL-72541 | Running the | These errors can be ignored. |
STL-72536 STL-72537 | CableInfo errors encountered when using the | Cable information reporting not currently supported. |
STL-72526 | The Fabric Manager system log port numbering is different from Switch CLI command port numbering. | For details, contact support@cornelis.com for technical advisory TA0061. |
STL-72420 | On some versions of RHEL 9.x, there is a known failure (rdmavt driver deadlock.) recorded in https://issues.redhat.com/browse/RHEL-83851. NOTE: Cornelis has not replicated this problem but it is possible that customers may be affected. | No workaround. |
STL-72160 | After uninstalling the meta packages with a package manager, several Cornelis Networks packages remain. | Refer to the CN5000 Maintenance and Troubleshooting Guide, “Remove OPX Software from a Host” for removal of the remaining packages. |
STL-71364 STL-72423 | Some legacy Omni-Path host utilities have been deprecated for CN5000 but are still supported for OPA100. | For a list of commands supported for CN5000, refer to the Man Pages or CN5000 Commands Guide. |
STL-67178 | After boot, the OPX Software hfi1-NVIDIA support is not available. | Review boot configuration to ensure that nvidia-driver will be available when hfi1 is loaded. |
Product Limitations
This release has the following limitations:
If you plan to deploy in a hybrid fabric with OPA100 and CN5000 interoperating together, contact support@cornelis.com for guidance before deploying this release.
Bulk Transfer Service is not available on port 1 of dual port SuperNIC cards.
When running MVAPICH3 with the OPX provider of libfabric, a
*** buffer overflow detected ***error may cause the job to terminate. This issue has been observed when running with a high number of processes, particularly when using 1 process per core (that is, the maximum number of processes the system can support). A workaround is to set the environment variableMV2_ENABLE_AFFINITY=0to disable CPU affinity.Queries to single port adapters will reflect that there are two ports with the first port always showing as offline.
Running of MPI jobs across both CN5000 and OPA100 components in hybrid fabrics (fabrics where CN5000 and OPA100 are connected) is not presently supported.
In the opafm.xml file, the default HFI port for fm0 must be set to "2" for proper operation:
<Name>fm0</Name> <Hfi>1</Hfi> <Port>2</Port>Non-default
MinShareVLMemandDedicatedVLMemvalues are not supported. Only use default values.FM Failover is presently not supported. Use a single Fabric Manager.
NVMe over Fabric is currently not supported.
Some distros versions may ship with ib_qib driver enabled. This driver is incompatible with the CN5000 OPX Software and may result in errors such as
disagrees about version of symbolin logs. Setblacklist ib_qib.During link bring up on a mixed OPA100/CN5000 fabric the FM log may show "Mismatch/Unable to set SCVL_t Map" warnings and link bounces may be observed as the fabric comes up. These messages and link bounces are expected on mixed fabrics and do not indicate a fault.
Enabling vFabrics with QoS results in Neighbor Mismatch/Unable to set SCVL_nt Map and Failed to init SL Maps in the log, and port bounces. There is no workaround. Port bounces are part of the standard recovery mechanism. These messages should only occur once and only when there is a change in the SCVL maps.
opainfo displays a single port adapter as a dual port adapter. No workaround. This is informational.
Ubuntu server fails to boot with more than one CN5000 SuperNIC installed. Ubuntu platforms cannot host multiple SuperNICs.
Bulk Transfer Service (BTS, bulksvc) is not supported on GPU platforms.
MVAPICH-Plus 4.1 for GPU is not supported.
The sph_exa application in SpecHPC hangs when using Open MPI. Set the following when running Open MPI:
-mca topo ^treematch
Preface
This document provides an overview of the changes introduced in this release. References to more detailed information are provided where necessary. The information contained in this document is intended as supplemental information only; it should be used in conjunction with the documentation provided for each component.
Software License Agreement
The software is provided under license agreements and may contain third-party software under separate third-party licensing. Refer to the license files provided with the software for specific details.
If You Need Help
Technical support for all Cornelis products is available 24 hours a day, 365 days a year.
For additional details:
Visit the Cornelis Support page at http://www.cornelisnetworks.com/support
Contact email: support@cornelisnetworks.com
Release Compatibility
This release is backward compatible with the most recent minor release version. For example, Release 12.N is backward compatible with Release 12.N-1 and Release 12.N-1.x.
New in This Release
The following features are new in this release:
Maintenance Updates
MPI and Verbs Performance Improvement
Release Items
The following software package is available for this release:
CN5000_OPXSoftware-<DISTRO>-12.1.2.0.40.tgz
Note
OS RPMs may need to be installed prior to software installation. Dependencies will be flagged during installation.
The following table lists meta package files provided for this release.
RPM Name | Description |
|---|---|
RHEL and SLES | |
cn5000_pkgs_cuda_meta-12_1_2_0-40.x86_64.rpm | CN5000 Meta Package containing all of the required CUDA RPMs |
cn5000_pkgs_non_gpu_meta-12_1_2_0-40.x86_64.rpm | CN5000 Meta Package containing all of the required RPMs |
cn5000_pkgs_rocm_meta-12_1_2_0-40.x86_64.rpm | CN5000 Meta Package containing all of the required ROCm RPMs |
Ubuntu | |
cn5000-pkgs-cuda-meta_12.1.2.0.40-amd64.deb | CN5000 Meta Package containing all of the required CUDA DEBs |
cn5000-pkgs-non-gpu-meta_12.1.2.0.40-amd64.deb | CN5000 Meta Package containing all of the required DEBs |
cn5000-pkgs-rocm-meta_12.1.2.0.40-amd64.deb | CN5000 Meta Package containing all of the required ROCm DEBs |
Refer to Appendix D, Release Package Manifest for the list of RPM and DEB files provided in this release.
System Requirements
This section lists the compatible operating systems and supported hardware.
Operating Systems
This release of the CN5000 OPX Software supports the operating systems listed in the following table.
Operating System | Base Kernel Version |
|---|---|
RHEL 9.4 | 5.14.0-427.13.1el9_4.x86_64 |
RHEL 9.5 | 5.14.0-503.11.1.el9_5.x86_64 |
RHEL 9.6 | 5.14.0-570.12.1.el9_6.x86_64 |
RHEL 9.7 | 5.14.0-611.5.1.el9_7.x86_64 |
RHEL 10.0 | 6.12.0-55.9.1.el10_0.x86_64 |
Rocky Linux 9.5 | 5.14.0-503.14.1.el9_5.x86_64 |
Rocky Linux 9.6 | 5.14.0-570.17.1el9_6.x86_64 |
Rocky Linux 9.7 | 5.14.0-611.5.1.el9_7.x86_64 |
Rocky Linux 10.0 | 6.12.0-55.12.1.el10_0.x86_64 |
SLES 15 SP7 | 6.4.0-150700.53.22.1-default |
Ubuntu 24.04 LTS | 6.8.0-90-generic |
Supported GPU Software
This release supports the GPU Software versions listed in the following table.
Note
The libfabric source rpm can be rebuilt to work with other ROCm and CUDA versions. Contact support@cornelis.com for assistance if needed.
Operating System | ROCm Version | CUDA Version |
|---|---|---|
RHEL/Rocky 9.4 | 6.2.0 | 13.1 |
RHEL/Rocky 9.5 | 6.3.0 | 13.1 |
RHEL/Rocky 9.6 | 6.4.2 | 12.9 |
RHEL/Rocky 9.7 | 7.1.1 | 13.1 |
RHEL/Rocky 10 | 7.1.1 | 13.1 |
SLES 15 SP7 | 6.4.3 | 13.0 |
Ubuntu 24.04 | 6.1.2 | 12.9 |
Supported Hardware
The following tables list the hardware supported in this release.
Hardware | Description |
|---|---|
CN5000 Switch | |
CN5000 Switch, 48-Port, CN5SWE48G2AF | 240/277 VAC in, Dual Power Supply, Air-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2AP | 240/277 VAC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48G2WF | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2WP | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2AP | 48 VDC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2WP | 48 VDC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Director Class Switch and Components | |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAB | 240/277 VAC in, Air-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAC | 240/277 VAC in, Air-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48A | 48-Port, Air-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01A | Air-Cooled |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWB | 240/277 VAC in, Liquid-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWC | 240/277 VAC in, Liquid-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48W | 48-Port, Liquid-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01W | Liquid-Cooled |
Hardware | Description |
|---|---|
CN5000 SuperNIC, CN5HFA2D5ALS | Dual Port, QSFP-DD, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5ALS | Single Port, QSFP, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5NLS | Single Port, QSFP, x16 PCIe Gen 5, Conduction-Cooled, Low Profile, Single |
Hardware | Description |
|---|---|
CPUs | |
4th Gen AMD EPYC Processor | Genoa Zen 4 CPU-based servers |
5th Gen AMD EPYC Processor | Turin Zen 5 CPU-based servers |
4th Generation Intel Xeon Scalable Processor | Sapphire Rapids CPU-based servers |
5th Generation Intel Xeon Scalable Processor | Emerald Rapids CPU-based servers |
GPUs | |
AMD Instinct MI Series GPU | AMD Instinct MI300X and MI200 series Graphic Processing Units |
NVIDIA GPUs | NVIDIA Tesla V100 and later |
Installation Requirements
Refer to the CN5000 Fabric Installation Guide for related software requirements and complete installation procedures.
Best Practices
To obtain the most recent functional and security updates, Cornelis recommends that you download and install the latest versions of the CN5000 Omni-Path software and firmware. Software and Documentation are found in the Cornelis Customer Center.
To ensure optimal performance in your CN5000 fabric, it is important to review the Cornelis performance tuning recommendations in the CN5000 Performance Tuning Guide.
Disable the Repository After OPX Software Installation
Required for RHEL 9.5.
After installing or updating the OPX Software, disable the repository on every node using one of the following methods:
Run the following command:
sudo dnf config-manager --set-disabled <repo>
In the repository file, change
enableto0.
Issues
This section lists the resolved and open issues.
Resolved Issues
The following table lists issues that are resolved in this release.
ID | Description | Resolved in Release |
|---|---|---|
STL-76263 | In some circumstances, rebooting a host may cause a panic. | 12.1.2 |
STL-76108 | SR-IOV Virtual Function devices on CN5000 cannot query the Subnet Administration. | 12.1.2 |
STL-75394 | On some systems running Ubuntu 24.04, the hfi1 driver may fail to start when it is unloaded and reloaded. The system log will contain a message saying | 12.1.2 |
STL-74593 | The Quantum Espresso application with Intel MPI may abort with SIGABRT when executed with a higher number of MPI ranks than available user HFI contexts and multiple endpoints per HFI context (FI_OPX_ENDPOINTS_PER_HFI_CONTEXT=2) | 12.1.2 |
STL-74230 | IPoIB interfaces on CN5000 currently do not support failover with the Channel Bonding driver in the Linux kernel. | 12.1.2 |
STL-73709 | The | 12.1.2 |
STL-73330 | Some LS-DYNA R14.1.0. benchmarks hang with Open MPI when using the OPX Provider for libfabric. | 12.1.2 |
STL-72649 | An Open MPI error may occur when using | 12.1.2 |
STL-72431 | The command | 12.1.2 |
STL-76222 | Memory overflow may occur when running MVAPICH on Ubuntu platforms. | 12.1.1 |
STL-76135 | When using SR-IOV, jobs running high processes per node (PPN) may fail on virtual machines with limited resources. | 12.1.1 |
STL-75555 | Errors can occur when installing Ubuntu meta-packages with | 12.1.1 |
STL-75331 | Using RDMA Core persistent names with settings other than KERNEL will result in RCCL segmentation faults. | 12.1.1 |
STL-70422 | RCCL hangs on AMD GPUs with opx and aws-ofi-rccl plugin. | 12.1.1 |
STL-76376 | Kernel crash may occur when hfi1 module is loaded with | 12.1.0.1 |
STL-76375 | MPI or middleware using the OPX Libfabric Provider may experience unreliable results. | 12.1.0.1 |
STL-76373 | Benign hfi1 messages relating to MCTXT interrupt in kernel logs can be ignored. | 12.1.0.1 |
STL-75066 | If IPv6 is enabled on any IPoIB interfaces, the FM sweeps constantly due to changes in multicast group membership. | 12.1.0 |
STL-74951 STL-74672 | On rare occasions, application hangs with an SDMA engine error in DMSG have been observed. | 12.1.0 |
STL-74696 | When running an NVIDIA GPU Cloud (NGC) container such as the "NVIDIA HPC-Benchmarks" package, a segmentation fault may occur. | 12.1.0 |
STL-74672 | On rare occasions, application hangs with an SDMA engine error in DMSG have been observed. | 12.1.0 |
STL-74234 | The mvapich2 packages provided with OPX Software should be ignored and not used. | 12.1.0 |
STL-74218 | IPoIB interfaces on CN5000 currently do not support failover with the Channel Bonding driver in the Linux kernel. | 12.1.0 |
STL-73861 | Hangs occur when using NVMe over Fabric. | 12.1.0 |
STL-73759 | When the FM restarts, different LIDs may get assigned to the nodes. | 12.1.0 |
STL-73267 | When running the | 12.1.0 |
STL-73245 | CN5000 Switch-Switch links do not appear in either | 12.1.0 |
STL-72864 | High CPU utilization seen for hfi1 related interrupts, potentially impacting performance. | 12.1.0 |
STL-72815 |
| 12.1.0 |
STL-72640 | In some cases the dmesg log may contain a message stating:
| 12.1.0 |
STL-72575 | TID updates under heavy load may result in an | 12.1.0 |
STL-72572 | In | 12.1.0 |
STL-72547 | Class Port Info queries are not reporting properly. | 12.1.0 |
Open Issues
The following tables list the open issues for this release.
ID | Description | Workaround |
|---|---|---|
STL-77956 | GPU applications hang with Open MPI 5.0.8 and earlier | Use Open MPI 5.0.9 or newer. |
STL-77873 | Megatron-LM training (Llama3-8B) hangs on multi-node configurations when using | Use |
STL-77578 | CableInfo errors encountered when using the | Use LID-routed packets to get cable information. |
STL-76942 | Lustre errors occur with Bulk Transfer Service (BTS) enabled (hfi1 driver parameter | When mounting Lustre, BTS should not be enabled ( |
STL-76907 | The following Lustre Error may occur: Write request failed with -14 NOTE: This is a general defect that affects all Lustre 2.17.0 stacks (refer to Lustre-Release Issue #16 | Avoid this issue by disabling hybrid IO functionality using the following command on the MGS server: lctl set_param -P llite.*.hybrid_io=0 |
STL-76435 |
Invalid Attribute or Attribute Modifier NOTE: The PMA response has a maximum payload size that limits the number of ports that can be returned in a single query. | Split the port select mask ( For example, on a 48-port switch, query ports in groups of 20 or fewer:
|
STL-76348 | Running | None. |
STL-76323 | SuperNICs may intermittently fail to enumerate on the PCIe bus or initialize after a cold boot or power cycle. In affected systems, one or more SuperNICs may be absent from the OS, preventing the node from participating in the fabric until the device is successfully detected and initialized. | Power cycle the server. |
STL-76313 | Kernel messages such as the following may be seen: CPORT request wait interrupted Dropping incoming CPORT message | Set the hfi1 module parameter |
STL-76144 | Setting the link speed policy to 100G in the opafm.xml file results in the following Fabric Manager error: Invalid Value for Link Speed Policy: 100G | Set the link speed using the Switch CLI command |
STL-76137 | Open MPI traffic fails on SR-IOV Virtual Function devices. | Use the |
STL-76131 | When using SR-IOV, the dmesg log in the VMs may occasionally show the following warning message: memcpy: detected field-spanning write | Do not run Omni-Path management tools, such as |
STL-75568 | Performance test failures may occur when running ib_send_bw and ib_read_bw with the | Do not use the |
STL-75535 | GADGET4 MPI application hangs with OPX Provider. | Contact support@cornelis.com. |
STL-75526 | After installing the OPX Software package on Ubuntu, the opafm service is enabled by default. | Manually disable the opafm service by default. |
STL-75484 | Running | To drop and reinitialize a link, use the Alternately, if |
STL-75395 | When | Disable |
STL-75362 | When using the TCP provider of libfabric, some MPI application may perform poorly or hang when launched with 1 process per core. This has been observed in benchmarks such as OSU Congestion, OSU Collectives, and IMB P2P. | For best results, users should use the OPX provider whenever available. OPX can be explicitly selected by setting the environment variable, |
STL-75322 | Upon reverting from 12.0.3 to a previous RHEL/Rocky release certain packages may not be removed. | Use the following command to remove the remaining packages: dnf remove ibacm infiniband-diags libfabric libhfi1verbs libibumad libibverbs libpsm2 librdmacm librdmacm-utils mpi-selector opa-basic-tools opa-fastfabric opa-fm opa-libopamgt rdma-core rdma-core-devel srp_daemon |
STL-75031 STL-76644 | MPI RMA benchmarks may produce an SDMA error (bad address) when using the OPX libfabric provider and environment variable FI_OPX_MIXED_NETWORK=0. | FI_OPX_MIXED_NETWORK is deprecated and should no longer be set. Contact support@cornelis.com. |
STL-74968 | Updating the Fabric Manager using DNF may not succeed even though an update is available. | Perform the following:
|
STL-74933 | Entries of the form | These messages can be ignored. |
STL-74679 | While running IPoIB in Connected mode, application hangs have been observed. | Configure IPoIB to Datagram mode and rerun the application. |
STL-74625 | When using both ports of a dual-port SuperNIC, the | Use |
STL-74504 | Occasional drops in bandwidth observed during microbenchmark testing. | Refer to the Performance Tuning Guide for platform-specific tuning. |
STL-74477 | Building opxs-kernel-updates from the src.rpm file fails with | Use an environment variable to allow the header file to be detected and used in the build: NVIDIA_DIR=$(ls -d /usr/src/nvidia-* | head -1)
ln -s ${NVIDIA_DIR}/nvidia /usr/src/kernels/5.14.0-503.14.1.el9_5.x86_64/include/nvidiaNote that the exact directory required for the symbolic link will depend on your kernel version. |
STL-74025 | When using IPoIB on CN5000, SuperNICs do not change MTU or join MC groups automatically. | Use the |
STL-73928 | HFI links bounce and the SM reports mapping warnings following the second FM restart. | No Workaround. Links that bounce recover and the fabric stabilizes. |
STL-73738 | Reloading the ipoib kernel module without also reloading the hfi1 module may cause FM errors. | To avoid this, always reload the hfi1 module along with the ipoib module. |
STL-73716 | The | Ignore the congestion flag. |
STL-73714 | Performing an | Counter values in this scenario should be ignored. |
STL-73713 | In a fabric with no data traffic, the Xmit Time Congestion port counter will increment. | No workaround. |
STL-73669 | Executing | The message may be ignored. |
STL-73531 | Configuring more than two data VLs is not currently supported. Doing so may lead to incorrect mappings of SC to VL. | Limit the number of configured data VLs to two. |
STL-73215 | When running | Use |
STL-73160 | The comments in the Adaptive Routing section of the opafm.xml file do not explain which settings are required for MGAR or for FGAR. | Currently the only field related to FGAR is
All other fields are related to legacy MGAR and will be ignored if |
STL-73140 | The following CN5000 commands do not work as expected:
| Note the following:
|
STL-72673 | OS-release file captured by opacapture is empty. | Use |
STL-72583 | In some cases the dmesg log may contain a message stating:
| This is cosmetic and will not affect functionality. |
STL-72573 | Hangs and errors have been seen in the OSU alltoall collective test when using the OPX Provider to libfabric with ROCm. | No workaround. |
STL-72541 | Running the | These errors can be ignored. |
STL-72536 STL-72537 | CableInfo errors encountered when using the | Cable information reporting not currently supported. |
STL-72526 | The Fabric Manager system log port numbering is different from Switch CLI command port numbering. | For details, contact support@cornelis.com for technical advisory TA0061. |
STL-72523 | Errors occur on RHEL 9.5 after installation of meta package. | Refer to Disable the Repository After OPX Software Installation. |
STL-72420 | On some versions of RHEL 9.x, there is a known failure (rdmavt driver deadlock.) recorded in https://issues.redhat.com/browse/RHEL-83851. NOTE: Cornelis has not replicated this problem but it is possible that customers may be affected. | No workaround. |
STL-72205 | FI_OPX_HFI_SELECT=[] does not correctly map to the available adapter in the case in which other adapters in the system have been disabled. | Unload and reload the driver. |
STL-72160 | After uninstalling the meta packages with a package manager, several Cornelis Networks packages remain. | Refer to the CN5000 Maintenance and Troubleshooting Guide, “Remove OPX Software from a Host” for removal of the remaining packages. |
STL-71364 STL-72423 | Some legacy Omni-Path host utilities have been deprecated for CN5000 but are still supported for OPA100. | For a list of commands supported for CN5000, refer to the Man Pages or CN5000 Commands Guide. |
STL-67178 | After boot, the OPX Software hfi1-NVIDIA support is not available. | Review boot configuration to ensure that nvidia-driver will be available when hfi1 is loaded. |
Product Limitations
This release has the following limitations:
If you plan to deploy in a hybrid fabric with OPA100 and CN5000 interoperating together, contact support@cornelis.com for guidance before deploying this release.
Bulk Transfer Service is not available on port 1 of dual port SuperNIC cards.
When running MVAPICH3 with the OPX provider of libfabric, a
*** buffer overflow detected ***error may cause the job to terminate. This issue has been observed when running with a high number of processes, particularly when using 1 process per core (that is, the maximum number of processes the system can support). A workaround is to set the environment variableMV2_ENABLE_AFFINITY=0to disable CPU affinity.Queries to single port adapters will reflect that there are two ports with the first port always showing as offline.
Running of MPI jobs across both CN5000 and OPA100 components in hybrid fabrics (fabrics where CN5000 and OPA100 are connected) is not presently supported.
In the opafm.xml file, the default HFI port for fm0 must be set to "2" for proper operation:
<Name>fm0</Name> <Hfi>1</Hfi> <Port>2</Port>Non-default
MinShareVLMemandDedicatedVLMemvalues are not supported. Only use default values.FM Failover is presently not supported. Use a single Fabric Manager.
NVMe over Fabric is currently not supported.
Some distros versions may ship with ib_qib driver enabled. This driver is incompatible with the CN5000 OPX Software and may result in errors such as
disagrees about version of symbolin logs. Setblacklist ib_qib.During link bring up on a mixed OPA100/CN5000 fabric the FM log may show "Mismatch/Unable to set SCVL_t Map" warnings and link bounces may be observed as the fabric comes up. These messages and link bounces are expected on mixed fabrics and do not indicate a fault.
Enabling vFabrics with QoS results in Neighbor Mismatch/Unable to set SCVL_nt Map and Failed to init SL Maps in the log, and port bounces. There is no workaround. Port bounces are part of the standard recovery mechanism. These messages should only occur once and only when there is a change in the SCVL maps.
opainfo displays a single port adapter as a dual port adapter. No workaround. This is informational.
Ubuntu server fails to boot with more than one CN5000 SuperNIC installed. Ubuntu platforms cannot host multiple SuperNICs.
Bulk Transfer Service (BTS, bulksvc) is not supported on GPU platforms.
MVAPICH-Plus 4.1 for GPU is not supported.
The sph_exa application in SpecHPC hangs when using Open MPI. Set the following when running Open MPI:
-mca topo ^treematch
Preface
This document provides an overview of the changes introduced in this release. References to more detailed information are provided where necessary. The information contained in this document is intended as supplemental information only; it should be used in conjunction with the documentation provided for each component.
Software License Agreement
The software is provided under license agreements and may contain third-party software under separate third-party licensing. Refer to the license files provided with the software for specific details.
If You Need Help
Technical support for all Cornelis products is available 24 hours a day, 365 days a year.
For additional details:
Visit the Cornelis Support page at http://www.cornelisnetworks.com/support
Contact email: support@cornelisnetworks.com
Release Compatibility
This release is backward compatible with the most recent minor release version. For example, Release 12.N is backward compatible with Release 12.N-1 and Release 12.N-1.x.
New in This Release
The following features are new in this release:
Maintenance Updates
Release Items
The following software package is available for this release:
CN5000_OPXSoftware-<DISTRO>-12.1.1.0.18.tgz
Note
OS RPMs may need to be installed prior to software installation. Dependencies will be flagged during installation.
The following table lists meta package files provided for this release.
RPM Name | Description |
|---|---|
RHEL and SLES | |
cn5000_pkgs_cuda_meta-12_1_1_0-18.x86_64.rpm | CN5000 Meta Package containing all of the required CUDA RPMs |
cn5000_pkgs_non_gpu_meta-12_1_1_0-18.x86_64.rpm | CN5000 Meta Package containing all of the required RPMs |
cn5000_pkgs_rocm_meta-12_1_1_0-18.x86_64.rpm | CN5000 Meta Package containing all of the required ROCm RPMs |
Ubuntu | |
cn5000-pkgs-cuda-meta_12.1.1.0.18-amd64.deb | CN5000 Meta Package containing all of the required CUDA DEBs |
cn5000-pkgs-non-gpu-meta_12.1.1.0.18-amd64.deb | CN5000 Meta Package containing all of the required DEBs |
cn5000-pkgs-rocm-meta_12.1.1.0.18-amd64.deb | CN5000 Meta Package containing all of the required ROCm DEBs |
Refer to Appendix E, Release Package Manifest for the list of RPM and DEB files provided in this release.
System Requirements
This section lists the compatible operating systems and supported hardware.
Operating Systems
This release of the CN5000 OPX Software supports the operating systems listed in the following table.
Operating System | Base Kernel Version |
|---|---|
RHEL 9.4 | 5.14.0-427.13.1el9_4.x86_64 |
RHEL 9.5 | 5.14.0-503.11.1.el9_5.x86_64 |
RHEL 9.6 | 5.14.0-570.12.1.el9_6.x86_64 |
RHEL 9.7 | 5.14.0-611.5.1.el9_7.x86_64 |
RHEL 10.0 | 6.12.0-55.9.1.el10_0.x86_64 |
Rocky Linux 9.5 | 5.14.0-503.14.1.el9_5.x86_64 |
Rocky Linux 9.6 | 5.14.0-570.17.1el9_6.x86_64 |
Rocky Linux 9.7 | 5.14.0-611.5.1.el9_7.x86_64 |
Rocky Linux 10.0 | 6.12.0-55.12.1.el10_0.x86_64 |
SLES 15 SP7 | 6.4.0-150700.53.22.1-default |
Ubuntu 24.04 LTS | 6.8.0-90-generic |
Note
AMD ROCm versions 6.4.1 and onward are not supported on RHEL/Rocky 9.5. Refer to the ROCm Compatibility Matrix.
Supported Hardware
The following tables list the hardware supported in this release.
Hardware | Description |
|---|---|
CN5000 Switch | |
CN5000 Switch, 48-Port, CN5SWE48G2AF | 240/277 VAC in, Dual Power Supply, Air-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2AP | 240/277 VAC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48G2WF | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2WP | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2AP | 48 VDC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2WP | 48 VDC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Director Class Switch and Components | |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAB | 240/277 VAC in, Air-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAC | 240/277 VAC in, Air-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48A | 48-Port, Air-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01A | Air-Cooled |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWB | 240/277 VAC in, Liquid-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWC | 240/277 VAC in, Liquid-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48W | 48-Port, Liquid-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01W | Liquid-Cooled |
Hardware | Description |
|---|---|
CN5000 SuperNIC, CN5HFA2D5ALS | Dual Port, QSFP-DD, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5ALS | Single Port, QSFP, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5NLS | Single Port, QSFP, x16 PCIe Gen 5, Conduction-Cooled, Low Profile, Single |
Hardware | Description |
|---|---|
CPUs | |
4th Gen AMD EPYC Processor | Genoa Zen 4 CPU-based servers |
5th Gen AMD EPYC Processor | Turin Zen 5 CPU-based servers |
4th Generation Intel Xeon Scalable Processor | Sapphire Rapids CPU-based servers |
5th Generation Intel Xeon Scalable Processor | Emerald Rapids CPU-based servers |
GPUs | |
AMD Instinct MI Series GPU | AMD Instinct MI300X and MI200 series Graphic Processing Units |
NVIDIA GPUs | NVIDIA Tesla V100 and later |
Installation Requirements
Refer to the CN5000 Fabric Installation Guide for related software requirements and complete installation procedures.
Best Practices
To obtain the most recent functional and security updates, Cornelis recommends that you download and install the latest versions of the CN5000 Omni-Path software and firmware. Software and Documentation are found in the Cornelis Customer Center.
To ensure optimal performance in your CN5000 fabric, it is important to review the Cornelis performance tuning recommendations in the CN5000 Performance Tuning Guide.
Disable the Repository After OPX Software Installation
Required for RHEL 9.5.
After installing or updating the OPX Software, disable the repository on every node using one of the following methods:
Run the following command:
sudo dnf config-manager --set-disabled <repo>
In the repository file, change
enableto0.
Issues
This section lists the resolved and open issues.
Resolved Issues
The following table lists issues that are resolved in this release.
ID | Description | Resolved in Release |
|---|---|---|
STL-76222 | Memory overflow may occur when running MVAPICH on Ubuntu platforms. | 12.1.1 |
STL-76135 | When using SR-IOV, jobs running high processes per node (PPN) may fail on virtual machines with limited resources. | 12.1.1 |
STL-75555 | Errors can occur when installing Ubuntu meta-packages with | 12.1.1 |
STL-75331 | Using RDMA Core persistent names with settings other than KERNEL will result in RCCL segmentation faults. | 12.1.1 |
STL-70422 | RCCL hangs on AMD GPUs with opx and aws-ofi-rccl plugin. | 12.1.1 |
STL-76376 | Kernel crash may occur when hfi1 module is loaded with | 12.1.0.1 |
STL-76375 | MPI or middleware using the OPX Libfabric Provider may experience unreliable results. | 12.1.0.1 |
STL-76373 | Benign hfi1 messages relating to MCTXT interrupt in kernel logs can be ignored. | 12.1.0.1 |
STL-75066 | If IPv6 is enabled on any IPoIB interfaces, the FM sweeps constantly due to changes in multicast group membership. | 12.1.0 |
STL-74951 STL-74672 | On rare occasions, application hangs with an SDMA engine error in DMSG have been observed. | 12.1.0 |
STL-74696 | When running an NVIDIA GPU Cloud (NGC) container such as the "NVIDIA HPC-Benchmarks" package, a segmentation fault may occur. | 12.1.0 |
STL-74672 | On rare occasions, application hangs with an SDMA engine error in DMSG have been observed. | 12.1.0 |
STL-74234 | The mvapich2 packages provided with OPX Software should be ignored and not used. | 12.1.0 |
STL-74218 | IPoIB interfaces on CN5000 currently do not support failover with the Channel Bonding driver in the Linux kernel. | 12.1.0 |
STL-73861 | Hangs occur when using NVMe over Fabric. | 12.1.0 |
STL-73759 | When the FM restarts, different LIDs may get assigned to the nodes. | 12.1.0 |
STL-73267 | When running the | 12.1.0 |
STL-73245 | CN5000 Switch-Switch links do not appear in either | 12.1.0 |
STL-72864 | High CPU utilization seen for hfi1 related interrupts, potentially impacting performance. | 12.1.0 |
STL-72815 |
| 12.1.0 |
STL-72640 | In some cases the dmesg log may contain a message stating:
| 12.1.0 |
STL-72575 | TID updates under heavy load may result in an | 12.1.0 |
STL-72572 | In | 12.1.0 |
STL-72547 | Class Port Info queries are not reporting properly. | 12.1.0 |
Open Issues
The following tables list the open issues for this release.
ID | Description | Workaround |
|---|---|---|
STL-76942 | Lustre errors occur with Bulk Transfer Service (BTS) enabled (hfi1 driver parameter | When mounting Lustre, BTS should not be enabled ( |
STL-76907 | The following Lustre Error may occur: Write request failed with -14 NOTE: This is a general defect that affects all Lustre 2.17.0 stacks (refer to Lustre-Release Issue #16 | Avoid this issue by disabling hybrid IO functionality using the following command on the MGS server: lctl set_param -P llite.*.hybrid_io=0 |
STL-76435 |
Invalid Attribute or Attribute Modifier NOTE: The PMA response has a maximum payload size that limits the number of ports that can be returned in a single query. | Split the port select mask ( For example, on a 48-port switch, query ports in groups of 20 or fewer:
|
STL-76348 | Running | None. |
STL-76323 | SuperNICs may intermittently fail to enumerate on the PCIe bus or initialize after a cold boot or power cycle. In affected systems, one or more SuperNICs may be absent from the OS, preventing the node from participating in the fabric until the device is successfully detected and initialized. | Power cycle the server. |
STL-76313 | Kernel messages such as the following may be seen: CPORT request wait interrupted Dropping incoming CPORT message | Set the hfi1 module parameter |
STL-76263 | In some circumstances, rebooting a host may cause a panic. | Power cycle the system. |
STL-76144 | Setting the link speed policy to 100G in the opafm.xml file results in the following Fabric Manager error: Invalid Value for Link Speed Policy: 100G | Set the link speed using the Switch CLI command |
STL-76137 | Open MPI traffic fails on SR-IOV Virtual Function devices. | Use the |
STL-76131 | When using SR-IOV, the dmesg log in the VMs may occasionally show the following warning message: memcpy: detected field-spanning write | Do not run Omni-Path management tools, such as |
STL-76108 | SR-IOV Virtual Function devices on CN5000 cannot query the Subnet Administration. | Do not run tools such as |
STL-75568 | Performance test failures may occur when running ib_send_bw and ib_read_bw with the | Do not use the |
STL-75535 | GADGET4 MPI application hangs with OPX Provider. | Contact support@cornelis.com. |
STL-75526 | After installing the OPX Software package on Ubuntu, the opafm service is enabled by default. | Manually disable the opafm service by default. |
STL-75484 | Running | To drop and reinitialize a link, use the Alternately, if |
STL-75395 | When | Disable |
STL-75394 | On some systems running Ubuntu 24.04, the hfi1 driver may fail to start when it is unloaded and reloaded. The system log will contain a message saying | If this message is seen, unload and reload the hfi1 driver again. |
STL-75362 | When using the TCP provider of libfabric, some MPI application may perform poorly or hang when launched with 1 process per core. This has been observed in benchmarks such as OSU Congestion, OSU Collectives, and IMB P2P. | For best results, users should use the OPX provider whenever available. OPX can be explicitly selected by setting the environment variable, |
STL-75322 | Upon reverting from 12.0.3 to a previous RHEL/Rocky release certain packages may not be removed. | Use the following command to remove the remaining packages: dnf remove ibacm infiniband-diags libfabric libhfi1verbs libibumad libibverbs libpsm2 librdmacm librdmacm-utils mpi-selector opa-basic-tools opa-fastfabric opa-fm opa-libopamgt rdma-core rdma-core-devel srp_daemon |
STL-75031 STL-76644 | MPI RMA benchmarks may produce an SDMA error (bad address) when using the OPX libfabric provider and environment variable FI_OPX_MIXED_NETWORK=0. | FI_OPX_MIXED_NETWORK is deprecated and should no longer be set. Contact support@cornelis.com. |
STL-74968 | Updating the Fabric Manager using DNF may not succeed even though an update is available. | Perform the following:
|
STL-74933 | Entries of the form | These messages can be ignored. |
STL-74679 | While running IPoIB in Connected mode, application hangs have been observed. | Configure IPoIB to Datagram mode and rerun the application. |
STL-74625 | When using both ports of a dual-port SuperNIC, the | Use |
STL-74593 | The Quantum Espresso application with Intel MPI may abort with SIGABRT when executed with a higher number of MPI ranks than available user HFI contexts and multiple endpoints per HFI context (FI_OPX_ENDPOINTS_PER_HFI_CONTEXT=2) | Set FI_OPX_ENDPOINTS_PER_HFI_CONTEXT=1 and reduce the number of MPI ranks to be less than or equal to the number of available HFI user contexts. |
STL-74504 | Occasional drops in bandwidth observed during microbenchmark testing. | Refer to the Performance Tuning Guide for platform-specific tuning. |
STL-74477 | Building opxs-kernel-updates from the src.rpm file fails with | Use an environment variable to allow the header file to be detected and used in the build: NVIDIA_DIR=$(ls -d /usr/src/nvidia-* | head -1)
ln -s ${NVIDIA_DIR}/nvidia /usr/src/kernels/5.14.0-503.14.1.el9_5.x86_64/include/nvidiaNote that the exact directory required for the symbolic link will depend on your kernel version. |
STL-74230 | IPoIB interfaces on CN5000 currently do not support failover with the Channel Bonding driver in the Linux kernel. | No workaround. |
STL-74025 | When using IPoIB on CN5000, SuperNICs do not change MTU or join MC groups automatically. | Use the |
STL-73928 | HFI links bounce and the SM reports mapping warnings following the second FM restart. | No Workaround. Links that bounce recover and the fabric stabilizes. |
STL-73738 | Reloading the ipoib kernel module without also reloading the hfi1 module may cause FM errors. | To avoid this, always reload the hfi1 module along with the ipoib module. |
STL-73716 | The | Ignore the congestion flag. |
STL-73714 | Performing an | Counter values in this scenario should be ignored. |
STL-73713 | In a fabric with no data traffic, the Xmit Time Congestion port counter will increment. | No workaround. |
STL-73709 | The | No workaround. |
STL-73669 | Executing | The message may be ignored. |
STL-73531 | Configuring more than two data VLs is not currently supported. Doing so may lead to incorrect mappings of SC to VL. | Limit the number of configured data VLs to two. |
STL-73330 | Some LS-DYNA R14.1.0. benchmarks hang with Open MPI when using the OPX Provider for libfabric. | Set the environment variable FI_OPX_RELIABILITY_SERVICE_USEC_MAX=5000. |
STL-73215 | When running | Use |
STL-73160 | The comments in the Adaptive Routing section of the opafm.xml file do not explain which settings are required for MGAR or for FGAR. | Currently the only field related to FGAR is
All other fields are related to legacy MGAR and will be ignored if |
STL-73140 | The following CN5000 commands do not work as expected:
| Note the following:
|
STL-72673 | OS-release file captured by opacapture is empty. | Use |
STL-72649 | An Open MPI error may occur when using | Contact support@cornelis.com. |
STL-72583 | In some cases the dmesg log may contain a message stating:
| This is cosmetic and will not affect functionality. |
STL-72573 | Hangs and errors have been seen in the OSU alltoall collective test when using the OPX Provider to libfabric with ROCm. | No workaround. |
STL-72541 | Running the | These errors can be ignored. |
STL-72536 STL-72537 | CableInfo errors encountered when using the | Cable information reporting not currently supported. |
STL-72526 | The Fabric Manager system log port numbering is different from Switch CLI command port numbering. | The port number used by the FM is equivalent to twice the switch CLI port name minus one. Contact Cornelis Customer Support for details. |
STL-72523 | Errors occur on RHEL 9.5 after installation of meta package. | Refer to Disable the Repository After OPX Software Installation. |
STL-72431 | The command | Use |
STL-72420 | On some versions of RHEL 9.x, there is a known failure (rdmavt driver deadlock.) recorded in https://issues.redhat.com/browse/RHEL-83851. NOTE: Cornelis has not replicated this problem but it is possible that customers may be affected. | No workaround. |
STL-72205 | FI_OPX_HFI_SELECT=[] does not correctly map to the available adapter in the case in which other adapters in the system have been disabled. | Unload and reload the driver. |
STL-72160 | After uninstalling the meta packages with a package manager, several Cornelis Networks packages remain. | Refer to the CN5000 Maintenance and Troubleshooting Guide, “Remove OPX Software from a Host” for removal of the remaining packages. |
STL-71364 STL-72423 | Some legacy Omni-Path host utilities have been deprecated for CN5000 but are still supported for OPA100. | For a list of commands supported for CN5000, refer to the Man Pages or CN5000 Commands Guide. |
STL-67178 | After boot, the OPX Software hfi1-NVIDIA support is not available. | Review boot configuration to ensure that nvidia-driver will be available when hfi1 is loaded. |
Product Limitations
This release has the following limitations:
Bulk Transfer Service is not available on port 1 of dual port SuperNIC cards.
When running MVAPICH3 with the OPX provider of libfabric, a
*** buffer overflow detected ***error may cause the job to terminate. This issue has been observed when running with a high number of processes, particularly when using 1 process per core (that is, the maximum number of processes the system can support). A workaround is to set environment variable,MV2_ENABLE_AFFINITY=0to disable CPU affinity.Queries to single port adapters will reflect that there are two ports with the first port always showing as offline.
Running of MPI jobs across both CN5000 and OPA100 components in hybrid fabrics (fabrics where CN5000 and OPA100 are connected) is not presently supported.
In the opafm.xml file, the default HFI port for fm0 must be set to "2" for proper operation:
<Name>fm0</Name> <Hfi>1</Hfi> <Port>2</Port>Non-default
MinShareVLMemandDedicatedVLMemvalues are not supported. Only use default values.FM Failover is presently not supported. Use a single Fabric Manager.
NVMe over Fabric is currently not supported.
Some distros versions may ship with ib_qib driver enabled. This driver is incompatible with the CN5000 OPX Software and may result in errors such as
disagrees about version of symbolin logs. Setblacklist ib_qib.During link bring up on a mixed OPA100/CN5000 fabric the FM log may show "Mismatch/Unable to set SCVL_t Map" warnings and link bounces may be observed as the fabric comes up. These messages and link bounces are expected on mixed fabrics and do not indicate a fault.
Enabling vFabrics with QoS results in Neighbor Mismatch/Unable to set SCVL_nt Map and Failed to init SL Maps in the log, and port bounces. There is no workaround. Port bounces are part of the standard recovery mechanism. These messages should only occur once and only when there is a change in the SCVL maps.
opainfo displays a single port adapter as a dual port adapter. No workaround. This is informational.
Ubuntu server fails to boot with more than one CN5000 SuperNIC installed. Ubuntu platforms cannot host multiple SuperNICs.
Bulk Transfer Service (BTS, bulksvc) is not supported on GPU platforms.
MVAPICH-Plus 4.1 for GPU is not supported.
Preface
This document provides an overview of the changes introduced in this release. References to more detailed information are provided where necessary. The information contained in this document is intended as supplemental information only; it should be used in conjunction with the documentation provided for each component.
Software License Agreement
The software is provided under license agreements and may contain third-party software under separate third-party licensing. Refer to the license files provided with the software for specific details.
If You Need Help
Technical support for all Cornelis products is available 24 hours a day, 365 days a year.
For additional details:
Visit the Cornelis Support page at http://www.cornelisnetworks.com/support
Contact email: support@cornelisnetworks.com
Release Compatibility
This release is backward compatible with the most recent minor release version. For example, Release 12.N is backward compatible with Release 12.N-1 and Release 12.N-1.x.
New in This Release
The following features are new in this release:
Support for new Operating Systems: RHEL/Rocky Linux 9.7 and 10.0
Single Root I/O Virtualization (SR-IOV)
Maintenance Updates
Release Items
The following software package is available for this release:
CN5000_OPXSoftware-<DISTRO>-12_1_0_1-4.tgz
Note
OS RPMs may need to be installed prior to software installation. Dependencies will be flagged during installation.
The following table lists meta package files provided for this release.
RPM Name | Description |
|---|---|
RHEL and SLES | |
cn5000_pkgs_cuda_meta-12_1_0_1-4.x86_64.rpm | CN5000 Meta Package containing all of the required CUDA RPMs |
cn5000_pkgs_non_gpu_meta-12_1_0_1-4.x86_64.rpm | CN5000 Meta Package containing all of the required RPMs |
cn5000_pkgs_rocm_meta-12_1_0_1-4.x86_64.rpm | CN5000 Meta Package containing all of the required ROCm RPMs |
Ubuntu | |
cn5000-pkgs-cuda-meta_12.1.0.1.4-amd64.deb | CN5000 Meta Package containing all of the required CUDA DEBs |
cn5000-pkgs-non-gpu-meta_12.1.0.1.4-amd64.deb | CN5000 Meta Package containing all of the required DEBs |
cn5000-pkgs-rocm-meta_12.1.0.1.4-amd64.deb | CN5000 Meta Package containing all of the required ROCm DEBs |
Refer to Appendix G, Release Package Manifest for the list of RPM and DEB files provided in this release.
System Requirements
This section lists the compatible operating systems and supported hardware.
Operating Systems
This release of the CN5000 OPX Software supports the operating systems listed in the following table.
Operating System | Base Kernel Version |
|---|---|
RHEL 9.4 | 5.14.0-427.13.1el9_4.x86_64 |
RHEL 9.5 | 5.14.0-503.11.1.el9_5.x86_64 |
RHEL 9.6 | 5.14.0-570.12.1.el9_6.x86_64 |
RHEL 9.7 | 5.14.0-611.5.1.el9_7.x86_64 |
RHEL 10.0 | 6.12.0-55.9.1.el10_0.x86_64 |
Rocky Linux 9.5 | 5.14.0-503.14.1.el9_5.x86_64 |
Rocky Linux 9.6 | 5.14.0-570.17.1el9_6.x86_64 |
Rocky Linux 9.7 | 5.14.0-611.5.1.el9_7.x86_64 |
Rocky Linux 10.0 | 6.12.0-55.12.1.el10_0.x86_64 |
SLES 15 SP7 | 6.4.0-150700.53.22.1-default |
Ubuntu 24.04 LTS | 6.8.0-90-generic |
Note
AMD ROCm versions 6.4.1 and onward are not supported on RHEL/Rocky 9.5. Refer to the ROCm Compatibility Matrix.
Supported Hardware
The following tables list the hardware supported in this release.
Hardware | Description |
|---|---|
CN5000 Switch | |
CN5000 Switch, 48-Port, CN5SWE48G2AF | 240/277 VAC in, Dual Power Supply, Air-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2AP | 240/277 VAC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48G2WF | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2WP | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2AP | 48 VDC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2WP | 48 VDC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Director Class Switch and Components | |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAB | 240/277 VAC in, Air-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAC | 240/277 VAC in, Air-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48A | 48-Port, Air-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01A | Air-Cooled |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWB | 240/277 VAC in, Liquid-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWC | 240/277 VAC in, Liquid-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48W | 48-Port, Liquid-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01W | Liquid-Cooled |
Hardware | Description |
|---|---|
CN5000 SuperNIC, CN5HFA2D5ALS | Dual Port, QSFP-DD, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5ALS | Single Port, QSFP, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5NLS | Single Port, QSFP, x16 PCIe Gen 5, Conduction-Cooled, Low Profile, Single |
Hardware | Description |
|---|---|
CPUs | |
4th Gen AMD EPYC Processor | Genoa Zen 4 CPU-based servers |
5th Gen AMD EPYC Processor | Turin Zen 5 CPU-based servers |
4th Generation Intel Xeon Scalable Processor | Sapphire Rapids CPU-based servers |
5th Generation Intel Xeon Scalable Processor | Emerald Rapids CPU-based servers |
GPUs | |
AMD Instinct MI Series GPU | AMD Instinct MI300X and MI200 series Graphic Processing Units |
NVIDIA GPUs | NVIDIA Tesla V100 and later |
Installation Requirements
Refer to the CN5000 Fabric Installation Guide for related software requirements and complete installation procedures.
Best Practices
To obtain the most recent functional and security updates, Cornelis recommends that you download and install the latest versions of the CN5000 Omni-Path software and firmware. Software and Documentation are found in the Cornelis Customer Center.
To ensure optimal performance in your CN5000 fabric, it is important to review the Cornelis performance tuning recommendations in the CN5000 Performance Tuning Guide.
Disable the Repository After OPX Software Installation
Required for RHEL 9.5.
After installing or updating the OPX Software, disable the repository on every node using one of the following methods:
Run the following command:
sudo dnf config-manager --set-disabled <repo>
In the repository file, change
enableto0.
Issues
This section lists the resolved and open issues.
Resolved Issues
The following table lists issues that are resolved in this release.
ID | Description | Resolved in Release |
|---|---|---|
STL-76376 | Kernel crash may occur when hfi1 module is loaded with | 12.1.0.1 |
STL-76375 | MPI or middleware using the OPX Libfabric Provider may experience unreliable results. | 12.1.0.1 |
STL-76373 | Benign hfi1 messages relating to MCTXT interrupt in kernel logs can be ignored. | 12.1.0.1 |
STL-75066 | If IPv6 is enabled on any IPoIB interfaces, the FM sweeps constantly due to changes in multicast group membership. | 12.1.0 |
STL-74951 STL-74672 | On rare occasions, application hangs with an SDMA engine error in DMSG have been observed. | 12.1.0 |
STL-74696 | When running an NVIDIA GPU Cloud (NGC) container such as the "NVIDIA HPC-Benchmarks" package, a segmentation fault may occur. | 12.1.0 |
STL-74672 | On rare occasions, application hangs with an SDMA engine error in DMSG have been observed. | 12.1.0 |
STL-74234 | The mvapich2 packages provided with OPX Software should be ignored and not used. | 12.1.0 |
STL-74218 | IPoIB interfaces on CN5000 currently do not support failover with the Channel Bonding driver in the Linux kernel. | 12.1.0 |
STL-73861 | Hangs occur when using NVMe over Fabric. | 12.1.0 |
STL-73759 | When the FM restarts, different LIDs may get assigned to the nodes. | 12.1.0 |
STL-73267 | When running the | 12.1.0 |
STL-73245 | CN5000 Switch-Switch links do not appear in either | 12.1.0 |
STL-72864 | High CPU utilization seen for hfi1 related interrupts, potentially impacting performance. | 12.1.0 |
STL-72815 |
| 12.1.0 |
STL-72640 | In some cases the dmesg log may contain a message stating:
| 12.1.0 |
STL-72575 | TID updates under heavy load may result in an | 12.1.0 |
STL-72572 | In | 12.1.0 |
STL-72547 | Class Port Info queries are not reporting properly. | 12.1.0 |
Open Issues
The following tables list the open issues for this release.
ID | Description | Workaround |
|---|---|---|
STL-76348 | Running | None. |
STL-76263 | In some circumstances, rebooting a host may cause a panic. | Power cycle the system. |
STL-76222 | Memory overflow may occur when running MVAPICH on Ubuntu platforms. | Set MVP_ENABLE_AFFINITY=0. |
STL-76218 | Crashes may occur when SuperNIC ports have inconsistent | Ensure that |
STL-76144 | Setting the link speed policy to 100G in the opafm.xml file results in the following Fabric Manager error: Invalid Value for Link Speed Policy: 100G | Set the link speed using the Switch CLI command |
STL-76137 | Open MPI traffic fails on SR-IOV Virtual Function devices. | Use the |
STL-76135 | When using SR-IOV, jobs running high processes per node (PPN) may fail on virtual machines with limited resources. | Ensure that the virtual machine is provisioned with at least twice the number of virtual CPUs as the desired number of processes to be run. |
STL-76131 | When using SR-IOV, the dmesg log in the VMs may occasionally show the following warning message: memcpy: detected field-spanning write | Do not run Omni-Path management tools, such as |
STL-76108 | SR-IOV Virtual Function devices on CN5000 cannot query the Subnet Administration. | Do not run tools such as |
STL-75568 | Performance test failures may occur when running ib_send_bw and ib_read_bw with the | Do not use the |
STL-75555 | Errors can occur when installing Ubuntu meta-packages with | Use one of the following:
|
STL-75535 | GADGET4 MPI application hangs with OPX Provider. | Set |
STL-75526 | After installing the OPX Software package on Ubuntu, the opafm service is enabled by default. | Manually disable the opafm service by default. |
STL-75484 | Running | To drop and reinitialize a link, use the Alternately, if |
STL-75395 | When | Disable |
STL-75394 | On some systems running Ubuntu 24.04, the hfi1 driver may fail to start when it is unloaded and reloaded. The system log will contain a message saying | If this message is seen, unload and reload the hfi1 driver again. |
STL-75362 | When using the TCP provider of libfabric, some MPI application may perform poorly or hang when launched with 1 process per core. This has been observed in benchmarks such as OSU Congestion, OSU Collectives, and IMB P2P. | For best results, users should use the OPX provider whenever available. OPX can be explicitly selected by setting the environment variable, |
STL-75331 | Using RDMA Core persistent names with settings other than KERNEL will result in RCCL segmentation faults. | Perform the following:
|
STL-75322 | Upon reverting from 12.0.3 to a previous RHEL/Rocky release certain packages may not be removed. | Use the following command to remove the remaining packages: dnf remove ibacm infiniband-diags libfabric libhfi1verbs libibumad libibverbs libpsm2 librdmacm librdmacm-utils mpi-selector opa-basic-tools opa-fastfabric opa-fm opa-libopamgt rdma-core rdma-core-devel srp_daemon |
STL-75031 | MPI RMA benchmarks may produce an SDMA error (bad address) when using the OPX libfabric provider and environment variable FI_OPX_MIXED_NETWORK=0. | Set FI_OPX_MIXED_NETWORK=1. |
STL-74968 | Updating the Fabric Manager using DNF may not succeed even though an update is available. | Perform the following:
|
STL-74933 | Entries of the form | These messages can be ignored. |
STL-74679 | While running IPoIB in Connected mode, application hangs have been observed. | Configure IPoIB to Datagram mode and rerun the application. |
STL-74625 | When using both ports of a dual-port SuperNIC, the | Use |
STL-74593 | The Quantum Espresso application with Intel MPI may abort with SIGABRT when executed with a higher number of MPI ranks than available user HFI contexts and multiple endpoints per HFI context (FI_OPX_ENDPOINTS_PER_HFI_CONTEXT=2) | Set FI_OPX_ENDPOINTS_PER_HFI_CONTEXT=1 and reduce the number of MPI ranks to be less than or equal to the number of available HFI user contexts. |
STL-74504 | Occasional drops in bandwidth observed during microbenchmark testing. | Refer to the Performance Tuning Guide for platform-specific tuning. |
STL-74477 | Building opxs-kernel-updates from the src.rpm file fails with | Use an environment variable to allow the header file to be detected and used in the build: NVIDIA_DIR=$(ls -d /usr/src/nvidia-* | head -1)
ln -s ${NVIDIA_DIR}/nvidia /usr/src/kernels/5.14.0-503.14.1.el9_5.x86_64/include/nvidiaNote that the exact directory required for the symbolic link will depend on your kernel version. |
STL-74230 | IPoIB interfaces on CN5000 currently do not support failover with the Channel Bonding driver in the Linux kernel. | No workaround. |
STL-74025 | When using IPoIB on CN5000, SuperNICs do not change MTU or join MC groups automatically. | Use the |
STL-73928 | HFI links bounce and the SM reports mapping warnings following the second FM restart. | No Workaround. Links that bounce recover and the fabric stabilizes. |
STL-73738 | Reloading the ipoib kernel module without also reloading the hfi1 module may cause FM errors. | To avoid this, always reload the hfi1 module along with the ipoib module. |
STL-73716 | The | Ignore the congestion flag. |
STL-73714 | Performing an | Counter values in this scenario should be ignored. |
STL-73713 | In a fabric with no data traffic, the Xmit Time Congestion port counter will increment. | No workaround. |
STL-73709 | The | No workaround. |
STL-73669 | Executing | The message may be ignored. |
STL-73531 | Configuring more than two data VLs is not currently supported. Doing so may lead to incorrect mappings of SC to VL. | Limit the number of configured data VLs to two. |
STL-73330 | Some LS-DYNA R14.1.0. benchmarks hang with Open MPI when using the OPX Provider for libfabric. | Set the environment variable FI_OPX_RELIABILITY_SERVICE_USEC_MAX=5000. |
STL-73215 | When running | Use |
STL-73160 | The comments in the Adaptive Routing section of the opafm.xml file do not explain which settings are required for MGAR or for FGAR. | Currently the only field related to FGAR is
All other fields are related to legacy MGAR and will be ignored if |
STL-73140 | The following CN5000 commands do not work as expected:
| Note the following:
|
STL-72673 | OS-release file captured by opacapture is empty. | Use |
STL-72649 | An Open MPI error may occur when using | Contact support@cornelis.com. |
STL-72583 | In some cases the dmesg log may contain a message stating:
| This is cosmetic and will not affect functionality. |
STL-72573 | Hangs and errors have been seen in the OSU alltoall collective test when using the OPX Provider to libfabric with ROCm. | No workaround. |
STL-72541 | Running the | These errors can be ignored. |
STL-72536 STL-72537 | CableInfo errors encountered when using the | Cable information reporting not currently supported. |
STL-72526 | The Fabric Manager system log port numbering is different from Switch CLI command port numbering. | The port number used by the FM is equivalent to twice the switch CLI port name minus one. Contact Cornelis Customer Support for details. |
STL-72523 | Errors occur on RHEL 9.5 after installation of meta package. | Refer to Disable the Repository After OPX Software Installation. |
STL-72431 | The command | Use |
STL-72420 | On some versions of RHEL 9.x, there is a known failure (rdmavt driver deadlock.) recorded in https://issues.redhat.com/browse/RHEL-83851. NOTE: Cornelis has not replicated this problem but it is possible that customers may be affected. | No workaround. |
STL-72205 | FI_OPX_HFI_SELECT=[] does not correctly map to the available adapter in the case in which other adapters in the system have been disabled. | Unload and reload the driver. |
STL-72160 | After uninstalling the meta packages with a package manager, several Cornelis Networks packages remain. | Refer to the CN5000 Maintenance and Troubleshooting Guide, “Remove OPX Software from a Host” for removal of the remaining packages. |
STL-71364 STL-72423 | Some legacy Omni-Path host utilities have been deprecated for CN5000 but are still supported for OPA100. | For a list of commands supported for CN5000, refer to the Man Pages or CN5000 Commands Guide. |
STL-70422 | RCCL hangs on AMD GPUs with opx and aws-ofi-rccl plugin. | Use Verbs over OPX Provider when using RCCL. |
STL-67178 | After boot, the OPX Software hfi1-NVIDIA support is not available. | Review boot configuration to ensure that nvidia-driver will be available when hfi1 is loaded. |
Product Limitations
This release has the following limitations:
Bulk Transfer Service is not available on port 1 of dual port SuperNIC cards.
When running MVAPICH3 with the OPX provider of libfabric, a
*** buffer overflow detected ***error may cause the job to terminate. This issue has been observed when running with a high number of processes, particularly when using 1 process per core (that is, the maximum number of processes the system can support). A workaround is to set environment variable,MV2_ENABLE_AFFINITY=0to disable CPU affinity.Queries to single port adapters will reflect that there are two ports with the first port always showing as offline.
Running of MPI jobs across both CN5000 and OPA100 components in hybrid fabrics (fabrics where CN5000 and OPA100 are connected) is not presently supported.
In the opafm.xml file, the default HFI port for fm0 must be set to "2" for proper operation:
<Name>fm0</Name> <Hfi>1</Hfi> <Port>2</Port>Non-default
MinShareVLMemandDedicatedVLMemvalues are not supported. Only use default values.FM Failover is presently not supported. Use a single Fabric Manager.
NVMe over Fabric is currently not supported.
Some distros versions may ship with ib_qib driver enabled. This driver is incompatible with the CN5000 OPX Software and may result in errors such as
disagrees about version of symbolin logs. Setblacklist ib_qib.During link bring up on a mixed OPA100/CN5000 fabric the FM log may show "Mismatch/Unable to set SCVL_t Map" warnings and link bounces may be observed as the fabric comes up. These messages and link bounces are expected on mixed fabrics and do not indicate a fault.
Enabling vFabrics with QoS results in Neighbor Mismatch/Unable to set SCVL_nt Map and Failed to init SL Maps in the log, and port bounces. There is no workaround. Port bounces are part of the standard recovery mechanism. These messages should only occur once and only when there is a change in the SCVL maps.
opainfo displays a single port adapter as a dual port adapter. No workaround. This is informational.
Ubuntu server fails to boot with more than one CN5000 SuperNIC installed. Ubuntu platforms cannot host multiple SuperNICs.
Bulk Transfer Service (BTS, bulksvc) is not supported on GPU platforms.
MVAPICH-Plus 4.1 for GPU is not supported.
Preface
This document provides an overview of the changes introduced in this release. References to more detailed information are provided where necessary. The information contained in this document is intended as supplemental information only; it should be used in conjunction with the documentation provided for each component.
Software License Agreement
The software is provided under license agreements and may contain third-party software under separate third-party licensing. Refer to the license files provided with the software for specific details.
If You Need Help
Technical support for all Cornelis products is available 24 hours a day, 365 days a year.
For additional details:
Visit the Cornelis Support page at http://www.cornelisnetworks.com/support
Contact email: support@cornelisnetworks.com
Release Compatibility
This release is backward compatible with the most recent minor release version. For example, Release 12.N is backward compatible with Release 12.N-1 and Release 12.N-1.x.
New in This Release
The following features are new in this release:
Support for new Operating Systems: RHEL/Rocky Linux 9.7 and 10.0
Single Root I/O Virtualization (SR-IOV)
Maintenance Updates
Release Items
The following software package is available for this release:
CN5000_OPXSoftware-<DISTRO>-12_1_0_0-80.tgz
Note
OS RPMs may need to be installed prior to software installation. Dependencies will be flagged during installation.
The following table lists meta package files provided for this release.
RPM Name | Description |
|---|---|
RHEL and SLES | |
cn5000_pkgs_cuda_meta-12_1_0_0-80.x86_64.rpm | CN5000 Meta Package containing all of the required CUDA RPMs |
cn5000_pkgs_non_gpu_meta-12_1_0_0-80.x86_64.rpm | CN5000 Meta Package containing all of the required RPMs |
cn5000_pkgs_rocm_meta-12_1_0_0-80.x86_64.rpm | CN5000 Meta Package containing all of the required ROCm RPMs |
Ubuntu | |
cn5000-pkgs-cuda-meta_12.1.0.0.80-amd64.deb | CN5000 Meta Package containing all of the required CUDA DEBs |
cn5000-pkgs-non-gpu-meta_12.1.0.0.80-amd64.deb | CN5000 Meta Package containing all of the required DEBs |
cn5000-pkgs-rocm-meta_12.1.0.0.80-amd64.deb | CN5000 Meta Package containing all of the required ROCm DEBs |
Refer to Appendix G, Release Package Manifest for the list of RPM and DEB files provided in this release.
System Requirements
This section lists the compatible operating systems and supported hardware.
Operating Systems
This release of the CN5000 OPX Software supports the operating systems listed in the following table.
Operating System | Base Kernel Version |
|---|---|
RHEL 9.4 | 5.14.0-427.13.1el9_4.x86_64 |
RHEL 9.5 | 5.14.0-503.11.1.el9_5.x86_64 |
RHEL 9.6 | 5.14.0-570.12.1.el9_6.x86_64 |
RHEL 9.7 | 5.14.0-611.5.1.el9_7.x86_64 |
RHEL 10.0 | 6.12.0-55.9.1.el10_0.x86_64 |
Rocky Linux 9.5 | 5.14.0-503.14.1.el9_5.x86_64 |
Rocky Linux 9.6 | 5.14.0-570.17.1el9_6.x86_64 |
Rocky Linux 9.7 | 5.14.0-611.5.1.el9_7.x86_64 |
Rocky Linux 10.0 | 6.12.0-55.12.1.el10_0.x86_64 |
SLES 15 SP7 | 6.4.0-150700.53.22.1-default |
Ubuntu 24.04 LTS | 6.8.0-90-generic |
Note
AMD ROCm versions 6.4.1 and onward are not supported on RHEL/Rocky 9.5. Refer to the ROCm Compatibility Matrix.
Supported Hardware
The following tables list the hardware supported in this release.
Hardware | Description |
|---|---|
CN5000 Switch | |
CN5000 Switch, 48-Port, CN5SWE48G2AF | 240/277 VAC in, Dual Power Supply, Air-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2AP | 240/277 VAC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48G2WF | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2WP | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2AP | 48 VDC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2WP | 48 VDC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Director Class Switch and Components | |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAB | 240/277 VAC in, Air-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KAC | 240/277 VAC in, Air-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48A | 48-Port, Air-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01A | Air-Cooled |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWB | 240/277 VAC in, Liquid-Cooled, Base Chassis |
CN5000 Director Class Switch, 12 Leaf Slots, CN5SWD12KWC | 240/277 VAC in, Liquid-Cooled, FRU Chassis |
CN5000 Director Class Switch, Leaf QSFP112 Module, CN5SWDLQ48W | 48-Port, Liquid-Cooled |
CN5000 Director Class Switch, Spine Module, CN5SWDSP01W | Liquid-Cooled |
Hardware | Description |
|---|---|
CN5000 SuperNIC, CN5HFA2D5ALS | Dual Port, QSFP-DD, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5ALS | Single Port, QSFP, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5NLS | Single Port, QSFP, x16 PCIe Gen 5, Conduction-Cooled, Low Profile, Single |
Hardware | Description |
|---|---|
CPUs | |
4th Gen AMD EPYC Processor | Genoa Zen 4 CPU-based servers |
5th Gen AMD EPYC Processor | Turin Zen 5 CPU-based servers |
4th Generation Intel Xeon Scalable Processor | Sapphire Rapids CPU-based servers |
5th Generation Intel Xeon Scalable Processor | Emerald Rapids CPU-based servers |
GPUs | |
AMD Instinct MI Series GPU | AMD Instinct MI300X and MI200 series Graphic Processing Units |
NVIDIA GPUs | NVIDIA Tesla V100 and later |
Installation Requirements
Refer to the CN5000 Fabric Installation Guide for related software requirements and complete installation procedures.
Best Practices
To obtain the most recent functional and security updates, Cornelis recommends that you download and install the latest versions of the CN5000 Omni-Path software and firmware. Software and Documentation are found in the Cornelis Customer Center.
To ensure optimal performance in your CN5000 fabric, it is important to review the Cornelis performance tuning recommendations in the CN5000 Performance Tuning Guide.
Disable the Repository After OPX Software Installation
Required for RHEL 9.5.
After installing or updating the OPX Software, disable the repository on every node using one of the following methods:
Run the following command:
sudo dnf config-manager --set-disabled <repo>
In the repository file, change
enableto0.
Issues
This section lists the resolved and open issues.
Resolved Issues
The following table lists issues that are resolved in this release.
ID | Description | Resolved in Release |
|---|---|---|
STL-75066 | If IPv6 is enabled on any IPoIB interfaces, the FM sweeps constantly due to changes in multicast group membership. | 12.1.0 |
STL-74951 STL-74672 | On rare occasions, application hangs with an SDMA engine error in DMSG have been observed. | 12.1.0 |
STL-74696 | When running an NVIDIA GPU Cloud (NGC) container such as the "NVIDIA HPC-Benchmarks" package, a segmentation fault may occur. | 12.1.0 |
STL-74672 | On rare occasions, application hangs with an SDMA engine error in DMSG have been observed. | 12.1.0 |
STL-74234 | The mvapich2 packages provided with OPX Software should be ignored and not used. | 12.1.0 |
STL-74218 | IPoIB interfaces on CN5000 currently do not support failover with the Channel Bonding driver in the Linux kernel. | 12.1.0 |
STL-73861 | Hangs occur when using NVMe over Fabric. | 12.1.0 |
STL-73759 | When the FM restarts, different LIDs may get assigned to the nodes. | 12.1.0 |
STL-73267 | When running the | 12.1.0 |
STL-73245 | CN5000 Switch-Switch links do not appear in either | 12.1.0 |
STL-72864 | High CPU utilization seen for hfi1 related interrupts, potentially impacting performance. | 12.1.0 |
STL-72815 |
| 12.1.0 |
STL-72640 | In some cases the dmesg log may contain a message stating:
| 12.1.0 |
STL-72575 | TID updates under heavy load may result in an | 12.1.0 |
STL-72572 | In | 12.1.0 |
STL-72547 | Class Port Info queries are not reporting properly. | 12.1.0 |
Open Issues
The following tables list the open issues for this release.
ID | Description | Workaround |
|---|---|---|
STL-76348 | Running | None. |
STL-76263 | In some circumstances, rebooting a host may cause a panic. | Power cycle the system. |
STL-76222 | Memory overflow may occur when running MVAPICH on Ubuntu platforms. | Set MVP_ENABLE_AFFINITY=0. |
STL-76218 | Crashes may occur when SuperNIC ports have inconsistent | Ensure that |
STL-76144 | Setting the link speed policy to 100G in the opafm.xml file results in the following Fabric Manager error: Invalid Value for Link Speed Policy: 100G | Set the link speed using the Switch CLI command |
STL-76137 | Open MPI traffic fails on SR-IOV Virtual Function devices. | Use the |
STL-76135 | When using SR-IOV, jobs running high processes per node (PPN) may fail on virtual machines with limited resources. | Ensure that the virtual machine is provisioned with at least twice the number of virtual CPUs as the desired number of processes to be run. |
STL-76131 | When using SR-IOV, the dmesg log in the VMs may occasionally show the following warning message: memcpy: detected field-spanning write | Do not run Omni-Path management tools, such as |
STL-76108 | SR-IOV Virtual Function devices on CN5000 cannot query the Subnet Administration. | Do not run tools such as |
STL-75568 | Performance test failures may occur when running ib_send_bw and ib_read_bw with the | Do not use the |
STL-75555 | Errors can occur when installing Ubuntu meta-packages with | Use one of the following:
|
STL-75535 | GADGET4 MPI application hangs with OPX Provider. | Set |
STL-75526 | After installing the OPX Software package on Ubuntu, the opafm service is enabled by default. | Manually disable the opafm service by default. |
STL-75484 | Running | To drop and reinitialize a link, use the Alternately, if |
STL-75395 | When | Disable |
STL-75394 | On some systems running Ubuntu 24.04, the hfi1 driver may fail to start when it is unloaded and reloaded. The system log will contain a message saying | If this message is seen, unload and reload the hfi1 driver again. |
STL-75362 | When using the TCP provider of libfabric, some MPI application may perform poorly or hang when launched with 1 process per core. This has been observed in benchmarks such as OSU Congestion, OSU Collectives, and IMB P2P. | For best results, users should use the OPX provider whenever available. OPX can be explicitly selected by setting the environment variable, |
STL-75331 | Using RDMA Core persistent names with settings other than KERNEL will result in RCCL segmentation faults. | Perform the following:
|
STL-75322 | Upon reverting from 12.0.3 to a previous RHEL/Rocky release certain packages may not be removed. | Use the following command to remove the remaining packages: dnf remove ibacm infiniband-diags libfabric libhfi1verbs libibumad libibverbs libpsm2 librdmacm librdmacm-utils mpi-selector opa-basic-tools opa-fastfabric opa-fm opa-libopamgt rdma-core rdma-core-devel srp_daemon |
STL-75031 | MPI RMA benchmarks may produce an SDMA error (bad address) when using the OPX libfabric provider and environment variable FI_OPX_MIXED_NETWORK=0. | Set FI_OPX_MIXED_NETWORK=1. |
STL-74968 | Updating the Fabric Manager using DNF may not succeed even though an update is available. | Perform the following:
|
STL-74933 | Entries of the form | These messages can be ignored. |
STL-74679 | While running IPoIB in Connected mode, application hangs have been observed. | Configure IPoIB to Datagram mode and rerun the application. |
STL-74625 | When using both ports of a dual-port SuperNIC, the | Use |
STL-74593 | The Quantum Espresso application with Intel MPI may abort with SIGABRT when executed with a higher number of MPI ranks than available user HFI contexts and multiple endpoints per HFI context (FI_OPX_ENDPOINTS_PER_HFI_CONTEXT=2) | Set FI_OPX_ENDPOINTS_PER_HFI_CONTEXT=1 and reduce the number of MPI ranks to be less than or equal to the number of available HFI user contexts. |
STL-74504 | Occasional drops in bandwidth observed during microbenchmark testing. | Refer to the Performance Tuning Guide for platform-specific tuning. |
STL-74477 | Building opxs-kernel-updates from the src.rpm file fails with | Use an environment variable to allow the header file to be detected and used in the build: NVIDIA_DIR=$(ls -d /usr/src/nvidia-* | head -1)
ln -s ${NVIDIA_DIR}/nvidia /usr/src/kernels/5.14.0-503.14.1.el9_5.x86_64/include/nvidiaNote that the exact directory required for the symbolic link will depend on your kernel version. |
STL-74230 | IPoIB interfaces on CN5000 currently do not support failover with the Channel Bonding driver in the Linux kernel. | No workaround. |
STL-74025 | When using IPoIB on CN5000, SuperNICs do not change MTU or join MC groups automatically. | Use the |
STL-73928 | HFI links bounce and the SM reports mapping warnings following the second FM restart. | No Workaround. Links that bounce recover and the fabric stabilizes. |
STL-73738 | Reloading the ipoib kernel module without also reloading the hfi1 module may cause FM errors. | To avoid this, always reload the hfi1 module along with the ipoib module. |
STL-73716 | The | Ignore the congestion flag. |
STL-73714 | Performing an | Counter values in this scenario should be ignored. |
STL-73713 | In a fabric with no data traffic, the Xmit Time Congestion port counter will increment. | No workaround. |
STL-73709 | The | No workaround. |
STL-73669 | Executing | The message may be ignored. |
STL-73531 | Configuring more than two data VLs is not currently supported. Doing so may lead to incorrect mappings of SC to VL. | Limit the number of configured data VLs to two. |
STL-73330 | Some LS-DYNA R14.1.0. benchmarks hang with Open MPI when using the OPX Provider for libfabric. | Set the environment variable FI_OPX_RELIABILITY_SERVICE_USEC_MAX=5000. |
STL-73215 | When running | Use |
STL-73160 | The comments in the Adaptive Routing section of the opafm.xml file do not explain which settings are required for MGAR or for FGAR. | Currently the only field related to FGAR is
All other fields are related to legacy MGAR and will be ignored if |
STL-73140 | The following CN5000 commands do not work as expected:
| Note the following:
|
STL-72673 | OS-release file captured by opacapture is empty. | Use |
STL-72649 | An Open MPI error may occur when using | Contact support@cornelis.com. |
STL-72583 | In some cases the dmesg log may contain a message stating:
| This is cosmetic and will not affect functionality. |
STL-72573 | Hangs and errors have been seen in the OSU alltoall collective test when using the OPX Provider to libfabric with ROCm. | No workaround. |
STL-72541 | Running the | These errors can be ignored. |
STL-72536 STL-72537 | CableInfo errors encountered when using the | Cable information reporting not currently supported. |
STL-72526 | The Fabric Manager system log port numbering is different from Switch CLI command port numbering. | The port number used by the FM is equivalent to twice the switch CLI port name minus one. Contact Cornelis Customer Support for details. |
STL-72523 | Errors occur on RHEL 9.5 after installation of meta package. | Refer to Disable the Repository After OPX Software Installation. |
STL-72431 | The command | Use |
STL-72420 | On some versions of RHEL 9.x, there is a known failure (rdmavt driver deadlock.) recorded in https://issues.redhat.com/browse/RHEL-83851. NOTE: Cornelis has not replicated this problem but it is possible that customers may be affected. | No workaround. |
STL-72205 | FI_OPX_HFI_SELECT=[] does not correctly map to the available adapter in the case in which other adapters in the system have been disabled. | Unload and reload the driver. |
STL-72160 | After uninstalling the meta packages with a package manager, several Cornelis Networks packages remain. | Refer to the CN5000 Maintenance and Troubleshooting Guide, “Remove OPX Software from a Host” for removal of the remaining packages. |
STL-71364 STL-72423 | Some legacy Omni-Path host utilities have been deprecated for CN5000 but are still supported for OPA100. | For a list of commands supported for CN5000, refer to the Man Pages or CN5000 Commands Guide. |
STL-70422 | RCCL hangs on AMD GPUs with opx and aws-ofi-rccl plugin. | Use Verbs over OPX Provider when using RCCL. |
STL-67178 | After boot, the OPX Software hfi1-NVIDIA support is not available. | Review boot configuration to ensure that nvidia-driver will be available when hfi1 is loaded. |
Product Limitations
This release has the following limitations:
Bulk Transfer Service is not available on port 1 of dual port SuperNIC cards.
When running MVAPICH3 with the OPX provider of libfabric, a
*** buffer overflow detected ***error may cause the job to terminate. This issue has been observed when running with a high number of processes, particularly when using 1 process per core (that is, the maximum number of processes the system can support). A workaround is to set environment variable,MV2_ENABLE_AFFINITY=0to disable CPU affinity.Queries to single port adapters will reflect that there are two ports with the first port always showing as offline.
Running of MPI jobs across both CN5000 and OPA100 components in hybrid fabrics (fabrics where CN5000 and OPA100 are connected) is not presently supported.
In the opafm.xml file, the default HFI port for fm0 must be set to "2" for proper operation:
<Name>fm0</Name> <Hfi>1</Hfi> <Port>2</Port>Non-default
MinShareVLMemandDedicatedVLMemvalues are not supported. Only use default values.FM Failover is presently not supported. Use a single Fabric Manager.
NVMe over Fabric is currently not supported.
Some distros versions may ship with ib_qib driver enabled. This driver is incompatible with the CN5000 OPX Software and may result in errors such as
disagrees about version of symbolin logs. Setblacklist ib_qib.During link bring up on a mixed OPA100/CN5000 fabric the FM log may show "Mismatch/Unable to set SCVL_t Map" warnings and link bounces may be observed as the fabric comes up. These messages and link bounces are expected on mixed fabrics and do not indicate a fault.
Enabling vFabrics with QoS results in Neighbor Mismatch/Unable to set SCVL_nt Map and Failed to init SL Maps in the log, and port bounces. There is no workaround. Port bounces are part of the standard recovery mechanism. These messages should only occur once and only when there is a change in the SCVL maps.
opainfo displays a single port adapter as a dual port adapter. No workaround. This is informational.
Ubuntu server fails to boot with more than one CN5000 SuperNIC installed. Ubuntu platforms cannot host multiple SuperNICs.
Bulk Transfer Service (BTS, bulksvc) is not supported on GPU platforms.
MVAPICH-Plus 4.1 for GPU is not supported.
Preface
This document provides an overview of the changes introduced in this release. References to more detailed information are provided where necessary. The information contained in this document is intended as supplemental information only; it should be used in conjunction with the documentation provided for each component.
Software License Agreement
The software is provided under license agreements and may contain third-party software under separate third-party licensing. Refer to the license files provided with the software for specific details.
If You Need Help
Technical support for all Cornelis products is available 24 hours a day, 365 days a year.
For additional details:
Visit the Cornelis Support page at http://www.cornelisnetworks.com/support
Contact email: support@cornelisnetworks.com
Release Compatibility
This release is backward compatible with the most recent minor release version. For example, Release 12.N is backward compatible with Release 12.N-1 and Release 12.N-1.x.
New in This Release
The following features are new in this release:
Support for the CN5000 product family as listed in Supported Hardware
Support for Operating Systems as listed in Operating Systems
OFI libfabric Support (OPX Provider)
OFA Verbs Support
CN5000 SuperNIC Kernel Driver
MPI Support (Intel MPI, Open MPI)
Storage Protocol Support (IPoIB, SRP, iSER, NVMe over Fabric)
Data Transfer Methods (PIO, DMA, Rendezvous)
GPU Support (CUDA, ROCm, RCCL, NCCL)
UEFI PXE Boot
Release Items
The following software is available for this release:
OS Version | Software Deliverables |
|---|---|
RHEL 9.4 | CN5000_OPXSoftware-RHEL9.4-12_0_2_0-16.tgz |
RHEL 9.5 | CN5000_OPXSoftware-RHEL9.5-12_0_2_0-16.tgz |
RHEL 9.6 | CN5000_OPXSoftware-RHEL9.6-12_0_2_0-16.tgz |
Note
OS RPMs may need to be installed prior to software installation. Dependencies will be flagged during installation.
The following table lists RPMs provided for this release.
RPM Name | Description |
|---|---|
CN5000-Packages-Public-GPG-Key.asc | GPG Key used to sign CN5000 OPX Software Packages |
cn5000_pkgs_cuda_meta-12_0_2_0-16.x86_64.rpm | CN5000 Meta Package containing all of the required CUDA RPMs |
cn5000_pkgs_non_gpu_meta-12_0_2_0-16.x86_64.rpm | CN5000 Meta Package containing all of the required RPMs |
cn5000_pkgs_rocm_meta-12_0_2_0-16.x86_64.rpm | CN5000 Meta Package containing all of the required ROCm RPMs |
hfi1-diagtools-sw-0.8-119.src.rpm | HFI1 Diagnostic Tools Software Source |
hfi1-diagtools-sw-0.8-119.x86_64.rpm | HFI1 Diagnostic Tools Software |
hfi1-diagtools-sw-debuginfo-0.8-119.x86_64.rpm | HFI1 Diagnostic Tools Software Debug Information |
hfi1-diagtools-sw-debugsource-0.8-119.x86_64.rpm | HFI1 Diagnostic Tools Software Debug Source |
hfi1-firmware-0.9-94.noarch.rpm | HFI Firmware |
hfi1-firmware_debug-0.9-94.noarch.rpm | HFI1 Firmware Debug |
libfabric-2.0.0-774.src.rpm | Libfabric Source for non-GPU |
libfabric-2.0.0-774.x86_64.rpm | Libfabric for non-GPU |
libfabric-2.0.0-774cuda.src.rpm | Libfabric Source for CUDA |
libfabric-2.0.0-774cuda.x86_64.rpm | Libfabric for CUDA |
libfabric-2.0.0-774rocm.src.rpm | Libfabric Source for ROCm |
libfabric-2.0.0-774rocm.x86_64.rpm | Libfabric for ROCm |
libfabric-devel-2.0.0-774.x86_64.rpm | Libfabric Development for non-GPU |
libfabric-devel-2.0.0-774cuda.x86_64.rpm | Libfabric Development for CUDA |
libfabric-devel-2.0.0-774rocm.x86_64.rpm | Libfabric Development for ROCm |
libfabric-psm2-2.0.0-774.src.rpm | (OPA100) Libfabric for PSM2 Source for non-GPU |
libfabric-psm2-2.0.0-774.x86_64.rpm | (OPA100) Libfabric for PSM2 for non-GPU |
libfabric-psm2-2.0.0-774cuda.src.rpm | (OPA100) Libfabric for PSM2 Source for CUDA |
libfabric-psm2-2.0.0-774cuda.x86_64.rpm | (OPA100) Libfabric for PSM2 for CUDA |
libfabric-verbs-2.0.0-774.src.rpm | Libfabric Verbs Source for non-GPU |
libfabric-verbs-2.0.0-774.x86_64.rpm | Libfabric Verbs for non-GPU |
libfabric-verbs-2.0.0-774cuda.src.rpm | Libfabric Verbs Source for CUDA |
libfabric-verbs-2.0.0-774cuda.x86_64.rpm | Libfabric Verbs for CUDA |
libpsm2-11.2.233-1.src.rpm | (OPA100) Libpsm2 Source for non-GPU |
libpsm2-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 for non-GPU |
libpsm2-11.2.233-1cuda.src.rpm | (OPA100) Libpsm2 Source for CUDA |
libpsm2-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 for CUDA |
libpsm2-compat-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 Compatibility for non-GPU |
libpsm2-compat-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 Compatibility for CUDA |
libpsm2-compat-debuginfo-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 Compatibility Debug Information for non-GPU |
libpsm2-compat-debuginfo-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 Compatibility Debug Information for CUDA |
libpsm2-debuginfo-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 Debug Information for non-GPU |
libpsm2-debuginfo-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 Debug Information for CUDA |
libpsm2-debugsource-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 Debug Source for non-GPU |
libpsm2-debugsource-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 Debug Source for CUDA |
libpsm2-devel-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 Development for non-GPU |
libpsm2-devel-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 Development for CUDA |
mpi-selector-1.0.3-1.src.rpm | MPI Selector Source |
mpi-selector-1.0.3-1.x86_64.rpm | MPI Selector |
mpitests-4.1-932.src.rpm | MPI Tests Source |
mpitests_mvapich2_gcc_hfi-4.1-932.x86_64.rpm | (OPA100) MPI Tests for MVAPICH GCC HFI |
mvapich2-2.3.7-6.src.rpm | (OPA100) MVAPICH2 Source |
mvapich2_gcc_hfi-2.3.7-6.x86_64.rpm | (OPA100) MVAPICH2 GCC HFI |
opa-12.0.2.0-5.el9.src.rpm | OPA Source |
opa-address-resolution-12.0.2.0-5.el9.x86_64.rpm | OPA Address Resolution |
opa-basic-tools-12.0.2.0-5.el9.x86_64.rpm | OPA Basic Tools |
opa-debuginfo-12.0.2.0-5.el9.x86_64.rpm | OPA Debug Information |
opa-fastfabric-12.0.2.0-5.el9.x86_64.rpm | OPA FastFabric Tools |
opa-fm-12.0.2.0-5.el9.src.rpm | OPA Fabric Manager Source |
opa-fm-12.0.2.0-5.el9.x86_64.rpm | OPA Fabric Manager |
opa-fm-debuginfo-12.0.2.0-5.el9.x86_64.rpm | OPA Fabric Manager Debug Information |
opa-libopamgt-12.0.2.0-5.el9.x86_64.rpm | OPA Libopamgt |
opa-libopamgt-devel-12.0.2.0-5.el9.x86_64.rpm | OPA Libopamgt Development |
opa-mpi-apps-12.0.2.0-5.el9.src.rpm | OPA MPI Applications Source |
opa-mpi-apps-12.0.2.0-5.el9.x86_64.rpm | OPA MPI Applications |
opa-scripts-1.2-2.noarch.rpm | OPA Scripts |
opa-scripts-1.2-2.src.rpm | OPA Scripts Source |
opaconfig-12.0.2.0-16.src.rpm | OPA Configuration Source |
opaconfig-12.0.2.0-16.x86_64.rpm | OPA Configuration |
RHEL 9.4: opxs-kernel-updates-5.14.0_427.13.1.el9_4.x86_64-48.src.rpm RHEL 9.5: opxs-kernel-updates-5.14.0_503.11.1.el9_5.x86_64-44.src.rpm RHEL 9.6: opxs-kernel-updates-5.14.0_570.12.1.el9_6.x86_64-80.src.rpm | OPXS Kernel Updates Source for non-GPU |
RHEL 9.4: opxs-kernel-updates-5.14.0_427.13.1.el9_4.x86_64-48cuda.src.rpm RHEL 9.5: opxs-kernel-updates-5.14.0_503.11.1.el9_5.x86_64-44cuda.src.rpm RHEL 9.6: opxs-kernel-updates-5.14.0_570.12.1.el9_6.x86_64-80cuda.src.rpm | OPXS Kernel Updates Source for CUDA |
RHEL 9.4: opxs-kernel-updates-5.14.0_427.13.1.el9_4.x86_64-48rocm.src.rpm RHEL 9.5: opxs-kernel-updates-5.14.0_503.11.1.el9_5.x86_64-44rocm.src.rpm RHEL 9.6: opxs-kernel-updates-5.14.0_570.12.1.el9_6.x86_64-80rocm.src.rpm | OPXS Kernel Updates Source for ROCm |
System Requirements
This section lists the compatible operating systems and supported hardware.
Operating Systems
This release of the CN5000 OPX Software supports the operating systems listed in the following table.
Operating System | Base Kernel Version |
|---|---|
RHEL 9.4 | 5.14.0-427.13.1el9_4x86_64 |
RHEL 9.5 | 5.14.0-503.11.1.el9_5x86_64 |
RHEL 9.6 | 5.14.0-570.12.1.el9_6x86_64 |
Rocky Linux 9.5 | 5.14.0-503.14.1.el9_4x86_64 |
Rocky Linux 9.6 | 5.14.0-570.17.1el9_6x86_64 |
Supported Hardware
The following tables list the hardware supported in this release.
Hardware | Description |
|---|---|
CN5000 Switch, 48-Port, CN5SWE48G2AF | 240/277 VAC in, Dual Power Supply, Air-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2AP | 240/277 VAC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48G2WF | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2WP | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2AP | 48 VDC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2WP | 48 VDC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
Hardware | Description |
|---|---|
CN5000 SuperNIC, CN5HFA2D5ALS | Dual Port, QSFP-DD, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5ALS | Single Port, QSFP, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5NLS | Single Port, QSFP, x16 PCIe Gen 5, Conduction-Cooled, Low Profile, Single |
Hardware | Description |
|---|---|
CPUs | |
4th Gen AMD EPYC Processor | Genoa Zen 4 CPU-based servers |
5th Gen AMD EPYC Processor | Turin Zen 5 CPU-based servers |
4th Generation Intel Xeon Scalable Processor | Sapphire Rapids CPU-based servers |
5th Generation Intel Xeon Scalable Processor | Emerald Rapids CPU-based servers |
GPUs | |
AMD Instinct MI Series GPU | AMD Instinct MI300X and MI200 series Graphic Processing Units |
NVIDIA GPUs | NVIDIA Tesla V100 and later |
Installation Requirements
Refer to the CN5000 Fabric Installation Guide for related software requirements and complete installation procedures.
Best Practices
To obtain the most recent functional and security updates, Cornelis recommends that you download and install the latest versions of the CN5000 Omni-Path software and firmware. Software and Documentation are found in the Cornelis Customer Center.
To ensure optimal performance in your CN5000 fabric, it is important to review the Cornelis performance tuning recommendations in the CN5000 Performance Tuning Guide.
Disable the Repository After OPX Software Installation
Required for RHEL 9.5.
After installing or updating the OPX Software, disable the repository on every node using one of the following methods:
Run the following command:
sudo dnf config-manager --set-disabled <repo>
In the repository file, change
enableto0.
Issues
This section lists the resolved and open issues.
Resolved Issues
The following table lists issues that are resolved in this release.
ID | Description | Resolved in |
|---|---|---|
STL-72640 | In some cases the dmesg log may contain a message stating:
| 12.0.2 |
STL-72572 | In | 12.0.2 |
Open Issues
The following tables list the open issues for this release.
ID | Description | Workaround |
|---|---|---|
STL-75031 | MPI RMA benchmarks may produce an SDMA error (bad address) when using the OPX libfabric provider and environment variable FI_OPX_MIXED_NETWORK=0. | Set FI_OPX_MIXED_NETWORK=1. |
STL-74968 | Updating the Fabric Manager using DNF may not succeed even though an update is available. | Perform the following:
|
STL-74951 STL-74672 | On rare occasions, application hangs with an SDMA engine error in DMSG have been observed. | None. Rerun the job. |
STL-74933 | Entries of the form | These messages can be ignored. |
STL-74696 | When running an NVIDIA GPU Cloud (NGC) container such as the "NVIDIA HPC-Benchmarks" package, a segmentation fault may occur. | Changes are required to the OPX configure file to include the appropriate Linux kernel user API ("uapi") directory. Contact support@cornelis.com. |
STL-74679 | While running IPoIB in Connected mode, application hangs have been observed. | Configure IPoIB to Datagram mode and rerun the application. |
STL-74625 | When using both ports of a dual-port SuperNIC, the | Use |
STL-74593 | The Quantum Espresso application with Intel MPI may abort with SIGABRT when executed with a higher number of MPI ranks than available user HFI contexts and multiple endpoints per HFI context (FI_OPX_ENDPOINTS_PER_HFI_CONTEXT=2). | Set FI_OPX_ENDPOINTS_PER_HFI_CONTEXT=1 and reduce the number of MPI ranks to be less than or equal to the number of available HFI user contexts. |
STL-74504 | Occasional drops in bandwidth observed during microbenchmark testing. | Refer to the Performance Tuning Guide for platform-specific tuning. |
STL-74477 | Building opxs-kernel-updates from the src.rpm file fails with | Use an environment variable to allow the header file to be detected and used in the build: NVIDIA_DIR=$(ls -d /usr/src/nvidia-* | head -1)
ln -s ${NVIDIA_DIR}/nvidia /usr/src/kernels/5.14.0-503.14.1.el9_5.x86_64/include/nvidiaNote that the exact directory required for the symbolic link will depend on your kernel version. |
STL-74234 | The mvapich2 packages provided with OPX Software should be ignored and not used. | Compile and use mvapich3 and/or mvapich4 (preferred) with CN5000 and libfabric/OPX provider. |
STL-74218 STL-74230 | IPoIB interfaces on CN5000 currently do not support failover with the Channel Bonding driver in the Linux kernel. | No workaround. |
STL-74025 | When using IPoIB on CN5000, SuperNICs do not change MTU or join MC groups automatically. | Use the |
STL-73928 | HFI links bounce and the SM reports mapping warnings following the second FM restart. | No Workaround. Links that bounce recover and the fabric stabilizes. |
STL-73759 | When the FM restarts, different LIDs may get assigned to the nodes. | None. However a second restart may reassign the LIDs back to the original values. |
STL-73738 | Reloading the ipoib kernel module without also reloading the hfi1 module may cause FM errors. | To avoid this, always reload the hfi1 module along with the ipoib module. |
STL-73716 | The | Ignore the congestion flag. |
STL-73714 | Performing an | Counter values in this scenario should be ignored. |
STL-73713 | In a fabric with no data traffic, the Xmit Time Congestion port counter will increment. | No workaround. |
STL-73709 | The | No workaround. |
STL-73669 | Executing | The message may be ignored. |
STL-73531 | Configuring more than two data VLs is not currently supported. Doing so may lead to incorrect mappings of SC to VL. | Limit the number of configured data VLs to two. |
STL-73401 | During link bring up on a mixed OPA100/CN5000 fabric the FM log may show | These messages and link bounces are expected on mixed fabrics and do not indicate a fault. |
STL-73330 | Some LS-DYNA R14.1.0. benchmarks hang with Open MPI when using the OPX Provider for libfabric. | Set the environment variable FI_OPX_RELIABILITY_SERVICE_USEC_MAX=5000. |
STL-73267 | When running the | No workaround. |
STL-73245 | CN5000 Switch-Switch links do not appear in either | No workaround. |
STL-73215 | When running | Use |
STL-73160 | The comments in the Adaptive Routing section of the opafm.xml file do not explain which settings are required for MGAR or for FGAR. | Currently the only field related to FGAR is
All other fields are related to legacy MGAR and will be ignored if |
STL-73140 | The following CN5000 commands do not work as expected:
| Note the following:
|
STL-72864 | High CPU utilization seen for hfi1 related interrupts, potentially impacting performance. | Use process pinning to avoid cores servicing hfi1 interrupts. |
STL-72815 |
| The duplicated entries can be ignored. |
STL-72805 | Enabling vFabrics with QoS results in | No workaround. Port bounces are part of the standard recovery mechanism. These messages should only occur once and only when there is a change in the SCVL maps. |
STL-72758 | Cableinfo errors may appear in the log file. | To suppress
|
STL-72673 | OS-release file captured by opacapture is empty. | Use |
STL-72649 | An Open MPI error may occur when using | Contact support@cornelis.com. |
STL-72622 |
| No workaround. This is informational. |
STL-72583 | In some cases the dmesg log may contain a message stating:
| This is cosmetic and will not affect functionality. |
STL-72575 | TID updates under heavy load may result in an | Reload the hfi1 driver with the module parameter |
STL-72573 | Hangs and errors have been seen in the OSU alltoall collective test when using the OPX Provider to libfabric with ROCm. | No workaround. |
STL-72555 |
| Use |
STL-72547 | Class Port Info queries are not reporting properly. | No workaround. |
STL-72541 | Running the | These errors can be ignored. |
STL-72536 STL-72537 | CableInfo errors encountered when using the | Cable information reporting not currently supported. |
STL-72526 | The Fabric Manager system log port numbering is different from Switch CLI command port numbering. | The port number used by the FM is equivalent to twice the switch CLI port name minus one. Contact Cornelis Customer Support for details. |
STL-72523 | Errors occur on RHEL 9.5 after installation of meta package. | Refer to Disable the Repository After OPX Software Installation. |
STL-72431 | The command | Use |
STL-72420 | On some versions of RHEL 9.x, there is a known failure (rdmavt driver deadlock.) recorded in https://issues.redhat.com/browse/RHEL-83851. NOTE: Cornelis has not replicated this problem but it is possible that customers may be affected. | No workaround. |
STL-72205 | FI_OPX_HFI_SELECT=[] does not correctly map to the available adapter in the case in which other adapters in the system have been disabled. | Unload and reload the driver. |
STL-72160 | After uninstalling the meta packages with a package manager, several Cornelis Networks packages remain. | Refer to the CN5000 Maintenance and Troubleshooting Guide, “Remove OPX Software from a Host” for removal of the remaining packages. |
STL-71364 STL-72423 | Some legacy Omni-Path host utilities have been deprecated for CN5000 but are still supported for OPA100. | For a list of commands supported for CN5000, refer to the Man Pages or CN5000 Commands Guide. |
STL-70422 | RCCL hangs on AMD GPUs with opx and aws-ofi-rccl plugin. | Use Verbs over OPX Provider when using RCCL. |
STL-67178 | After boot, the OPX Software hfi1-NVIDIA support is not available. | Review boot configuration to ensure that nvidia-driver will be available when hfi1 is loaded. |
STL-66199 | On RHEL 9.x, the Invalid MAD: Invalid Session ID Error: Failed to get ini descriptors - status 3 Error: Failed to acquire node description - status -1 Invalid MAD: Invalid Session ID Error: Failed to get ini descriptors - status 3 | Perform the following:
|
Product Limitations
This release has the following limitations:
Queries to single port adapters will reflect that there are two ports with the first port always showing as offline.
Running of MPI jobs across both CN5000 and OPA100 components in hybrid fabrics (fabrics where CN5000 and OPA100 are connected), is not presently supported.
In the opafm.xml file, the default HFI port for fm0 must be set to "2" for proper operation:
<Name>fm0</Name> <Hfi>1</Hfi> <Port>2</Port>Non-default
MinShareVLMemandDedicatedVLMemvalues are not supported. Only use default values.FM Failover is presently not supported. Use a single Fabric Manager.
When the PM is enabled and there is a disabled SuperNIC port in the fabric, a segfault may occur in the SM. Enable all disabled SuperNIC ports or disable the PM. Note that the SM will restart and the SM/PM will recover.
NVMe over Fabric is currently not supported.
ROCm 6.x is required when using AMD GPUs on RHEL/Rocky 9.4, 9.5 and 9.6.
Some distros versions may ship with ib_qib driver enabled. This driver is incompatible with the CN5000 OPX Software and may result in errors such as
disagrees about version of symbolin logs. Setblacklist ib_qib.
Preface
This document provides an overview of the changes introduced in this release. References to more detailed information are provided where necessary. The information contained in this document is intended as supplemental information only; it should be used in conjunction with the documentation provided for each component.
Software License Agreement
The software is provided under license agreements and may contain third-party software under separate third-party licensing. Refer to the license files provided with the software for specific details.
If You Need Help
Technical support for all Cornelis products is available 24 hours a day, 365 days a year.
For additional details:
Visit the Cornelis Support page at http://www.cornelisnetworks.com/support
Contact email: support@cornelisnetworks.com
Release Compatibility
This release is backward compatible with the most recent minor release version. For example, Release 12.N is backward compatible with Release 12.N-1 and Release 12.N-1.x.
New in This Release
The following features are new in this release:
Support for the CN5000 product family as listed in Supported Hardware
Support for Operating Systems as listed in Operating Systems
OFI libfabric Support (OPX Provider)
OFA Verbs Support
CN5000 SuperNIC Kernel Driver
MPI Support (Intel MPI, Open MPI)
Storage Protocol Support (IPoIB, SRP, iSER, NVMe over Fabric)
Data Transfer Methods (PIO, DMA, Rendezvous)
GPU Support (CUDA, ROCm, RCCL, NCCL)
Release Items
The following software is available for this release.
Note
Though the packages contain "CN5000" in the filename, they are applicable to Omni-Path Express 100.
OS Version | Software Deliverables |
|---|---|
RHEL 9.4 | CN5000_OPXSoftware-RHEL9.4-12.0.1.0.4.tgz |
RHEL 9.5 | CN5000_OPXSoftware-RHEL9.5-12.0.1.0.4.tgz |
RHEL 9.6 | CN5000_OPXSoftware-RHEL9.6-12.0.1.0.4.tgz |
Note
OS RPMs may need to be installed prior to software installation. Dependencies will be flagged during installation.
The following table lists RPMs provided for this release.
RPM Name | Description |
|---|---|
CN5000-Packages-Public-GPG-Key.asc | GPG Key used to sign CN5000 OPX Software Packages |
cn5000_pkgs_cuda_meta-12_0_1_0-4.x86_64.rpm | CN5000 Meta Package containing all of the required CUDA RPMs |
cn5000_pkgs_non_gpu_meta-12_0_1_0-4.x86_64.rpm | CN5000 Meta Package containing all of the required RPMs |
cn5000_pkgs_rocm_meta-12_0_1_0-4.x86_64.rpm | CN5000 Meta Package containing all of the required ROCm RPMs |
hfi1-diagtools-sw-0.8-119.src.rpm | HFI1 Diagnostic Tools Software Source |
hfi1-diagtools-sw-0.8-119.x86_64.rpm | HFI1 Diagnostic Tools Software |
hfi1-diagtools-sw-debuginfo-0.8-119.x86_64.rpm | HFI1 Diagnostic Tools Software Debug Information |
hfi1-diagtools-sw-debugsource-0.8-119.x86_64.rpm | HFI1 Diagnostic Tools Software Debug Source |
hfi1-firmware-0.9-94.noarch.rpm | HFI Firmware |
hfi1-firmware_debug-0.9-94.noarch.rpm | HFI1 Firmware Debug |
libfabric-2.0.0-755.src.rpm | Libfabric Source for non-GPU |
libfabric-2.0.0-755.x86_64.rpm | Libfabric for non-GPU |
libfabric-2.0.0-755cuda.src.rpm | Libfabric Source for CUDA |
libfabric-2.0.0-755cuda.x86_64.rpm | Libfabric for CUDA |
libfabric-2.0.0-755rocm.src.rpm | Libfabric Source for ROCm |
libfabric-2.0.0-755rocm.x86_64.rpm | Libfabric for ROCm |
libfabric-devel-2.0.0-755.x86_64.rpm | Libfabric Development for non-GPU |
libfabric-devel-2.0.0-755cuda.x86_64.rpm | Libfabric Development for CUDA |
libfabric-devel-2.0.0-755rocm.x86_64.rpm | Libfabric Development for ROCm |
libfabric-psm2-2.0.0-755.src.rpm | (OPA100) Libfabric for PSM2 Source for non-GPU |
libfabric-psm2-2.0.0-755.x86_64.rpm | (OPA100) Libfabric for PSM2 for non-GPU |
libfabric-psm2-2.0.0-755cuda.src.rpm | (OPA100) Libfabric for PSM2 Source for CUDA |
libfabric-psm2-2.0.0-755cuda.x86_64.rpm | (OPA100) Libfabric for PSM2 for CUDA |
libfabric-verbs-2.0.0-755.src.rpm | Libfabric Verbs Source for non-GPU |
libfabric-verbs-2.0.0-755.x86_64.rpm | Libfabric Verbs for non-GPU |
libfabric-verbs-2.0.0-755cuda.src.rpm | Libfabric Verbs Source for CUDA |
libfabric-verbs-2.0.0-755cuda.x86_64.rpm | Libfabric Verbs for CUDA |
libpsm2-11.2.233-1.src.rpm | (OPA100) Libpsm2 Source for non-GPU |
libpsm2-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 for non-GPU |
libpsm2-11.2.233-1cuda.src.rpm | (OPA100) Libpsm2 Source for CUDA |
libpsm2-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 for CUDA |
libpsm2-compat-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 Compatibility for non-GPU |
libpsm2-compat-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 Compatibility for CUDA |
libpsm2-compat-debuginfo-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 Compatibility Debug Information for non-GPU |
libpsm2-compat-debuginfo-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 Compatibility Debug Information for CUDA |
libpsm2-debuginfo-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 Debug Information for non-GPU |
libpsm2-debuginfo-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 Debug Information for CUDA |
libpsm2-debugsource-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 Debug Source for non-GPU |
libpsm2-debugsource-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 Debug Source for CUDA |
libpsm2-devel-11.2.233-1.x86_64.rpm | (OPA100) Libpsm2 Development for non-GPU |
libpsm2-devel-11.2.233-1cuda.x86_64.rpm | (OPA100) Libpsm2 Development for CUDA |
mpi-selector-1.0.3-1.src.rpm | MPI Selector Source |
mpi-selector-1.0.3-1.x86_64.rpm | MPI Selector |
mpitests-4.1-932.src.rpm | MPI Tests Source |
mpitests_mvapich2_gcc_hfi-4.1-932.x86_64.rpm | (OPA100) MPI Tests for MVAPICH GCC HFI |
mvapich2-2.3.7-6.src.rpm | (OPA100) MVAPICH2 Source |
mvapich2_gcc_hfi-2.3.7-6.x86_64.rpm | (OPA100) MVAPICH2 GCC HFI |
opa-12.0.1.0-3.el9.src.rpm | OPA Source |
opa-address-resolution-12.0.1.0-3.el9.x86_64.rpm | OPA Address Resolution |
opa-basic-tools-12.0.1.0-3.el9.x86_64.rpm | OPA Basic Tools |
opa-debuginfo-12.0.1.0-3.el9.x86_64.rpm | OPA Debug Information |
opa-fastfabric-12.0.1.0-3.el9.x86_64.rpm | OPA FastFabric Tools |
opa-fm-12.0.1.0-3.el9.src.rpm | OPA Fabric Manager Source |
opa-fm-12.0.1.0-3.el9.x86_64.rpm | OPA Fabric Manager |
opa-fm-debuginfo-12.0.1.0-3.el9.x86_64.rpm | OPA Fabric Manager Debug Information |
opa-libopamgt-12.0.1.0-3.el9.x86_64.rpm | OPA Libopamgt |
opa-libopamgt-devel-12.0.1.0-3.el9.x86_64.rpm | OPA Libopamgt Development |
opa-mpi-apps-12.0.1.0-3.el9.src.rpm | OPA MPI Applications Source |
opa-mpi-apps-12.0.1.0-3.el9.x86_64.rpm | OPA MPI Applications |
opa-scripts-1.2-2.noarch.rpm | OPA Scripts |
opa-scripts-1.2-2.src.rpm | OPA Scripts Source |
opaconfig-12.0.1.0-4.src.rpm | OPA Configuration Source |
opaconfig-12.0.1.0-4.x86_64.rpm | OPA Configuration |
RHEL 9.4: opxs-kernel-updates-5.14.0_427.13.1.el9_4.x86_64-29.src.rpm RHEL 9.5: opxs-kernel-updates-5.14.0_503.11.1.el9_5.x86_64-27.src.rpm RHEL 9.6: opxs-kernel-updates-5.14.0_570.12.1.el9_6.x86_64-63.src.rpm | OPXS Kernel Updates Source for non-GPU |
RHEL 9.4: opxs-kernel-updates-5.14.0_427.13.1.el9_4.x86_64-29cuda.src.rpm RHEL 9.5: opxs-kernel-updates-5.14.0_503.11.1.el9_5.x86_64-27cuda.src.rpm RHEL 9.6: opxs-kernel-updates-5.14.0_570.12.1.el9_6.x86_64-63cuda.src.rpm | OPXS Kernel Updates Source for CUDA |
RHEL 9.4: opxs-kernel-updates-5.14.0_427.13.1.el9_4.x86_64-29rocm.src.rpm RHEL 9.5: opxs-kernel-updates-5.14.0_503.11.1.el9_5.x86_64-27rocm.src.rpm RHEL 9.6: opxs-kernel-updates-5.14.0_570.12.1.el9_6.x86_64-63rocm.src.rpm | OPXS Kernel Updates Source for ROCm |
System Requirements
This section lists the compatible operating systems and supported hardware.
Operating Systems
This release of the CN5000 OPX Software supports the operating systems listed in the following table.
Operating System | Base Kernel Version |
|---|---|
RHEL 9.4 | 5.14.0-427.13.1el9_4x86_64 |
RHEL 9.5 | 5.14.0-503.11.1.el9_5x86_64 |
RHEL 9.6 | 5.14.0-570.12.1.el9_6x86_64 |
Rocky Linux 9.5 | 5.14.0-503.14.1.el9_4x86_64 |
Rocky Linux 9.6 | 5.14.0-570.17.1el9_6x86_64 |
Supported Hardware
The following tables list the hardware supported in this release.
Hardware | Description |
|---|---|
CN5000 Switch, 48-Port, CN5SWE48G2AF | 240/277 VAC in, Dual Power Supply, Air-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2AP | 240/277 VAC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48G2WF | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Fan-to-Port |
CN5000 Switch, 48-Port, CN5SWE48G2WP | 240/277 VAC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2AP | 48 VDC in, Dual Power Supply, Air-Cooled, Port-to-Fan |
CN5000 Switch, 48-Port, CN5SWE48D2WP | 48 VDC in, Dual Power Supply, Liquid-Cooled, Port-to-Fan |
Hardware | Description |
|---|---|
CN5000 SuperNIC, CN5HFA2D5ALS | Dual Port, QSFP-DD, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5ALS | Single Port, QSFP, x16 PCIe Gen 5, Air-Cooled, Low Profile, Single |
CN5000 SuperNIC, CN5HFA1Q5NLS | Single Port, QSFP, x16 PCIe Gen 5, Conduction-Cooled, Low Profile, Single |
Hardware | Description |
|---|---|
CPUs | |
4th Gen AMD EPYC Processor | Genoa Zen 4 CPU-based servers |
5th Gen AMD EPYC Processor | Turin Zen 5 CPU-based servers |
4th Generation Intel Xeon Scalable Processor | Sapphire Rapids CPU-based servers |
5th Generation Intel Xeon Scalable Processor | Emerald Rapids CPU-based servers |
GPUs | |
AMD Instinct MI Series GPU | AMD Instinct MI300X and MI200 series Graphic Processing Units |
NVIDIA GPUs | NVIDIA Tesla V100 and later |
Installation Requirements
Refer to the CN5000 Fabric Installation Guide for related software requirements and complete installation procedures.
Best Practices
To obtain the most recent functional and security updates, Cornelis recommends that you download and install the latest versions of the CN5000 Omni-Path software and firmware. Software and Documentation are found in the Cornelis Customer Center.
To ensure optimal performance in your CN5000 fabric, it is important to review the Cornelis performance tuning recommendations in the CN5000 Performance Tuning Guide.
Disable the Repository After OPX Software Installation
Required for RHEL 9.5.
After installing or updating the OPX Software, disable the repository on every node using one of the following methods:
Run the following command:
sudo dnf config-manager --set-disabled <repo>
In the repository file, change
enableto0.
Issues
This section lists the resolved and open issues.
Resolved Issues
None.
Open Issues
The following tables list the open issues for this release.
ID | Description | Workaround |
|---|---|---|
STL-74477 | Building opxs-kernel-updates from the src.rpm file fails with | Use an environment variable to allow the header file to be detected and used in the build: NVIDIA_DIR=$(ls -d /usr/src/nvidia-* | head -1)
ln -s ${NVIDIA_DIR}/nvidia /usr/src/kernels/5.14.0-503.14.1.el9_5.x86_64/include/nvidia |
STL-74234 | The mvapich2 packages provided with OPX Software should be ignored and not used. | Compile and use mvapich3 and/or mvapich4 (preferred) with CN5000 and libfabric/OPX provider. |
STL-74218 | IPoIB interfaces on CN5000 currently do not support failover with the Channel Bonding driver in the Linux kernel. | No workaround. |
STL-74025 | When using IPoIB on CN5000, SuperNICs do not change MTU or join MC groups automatically. | Use the |
STL-73928 | HFI links bounce and the SM reports mapping warnings following the second FM restart. | No Workaround. Links that bounce recover and the fabric stabilizes. |
STL-73759 | When the FM restarts, different LIDs may get assigned to the nodes. | None. However a second restart may reassign the LIDs back to the original values. |
STL-73738 | Reloading the ipoib kernel module without also reloading the hfi1 module may cause FM errors. | To avoid this, always reload the hfi1 module along with the ipoib module. |
STL-73716 | The | Ignore the congestion flag. |
STL-73714 | Performing an | Counter values in this scenario should be ignored. |
STL-73713 | In a fabric with no data traffic, the Xmit Time Congestion port counter will increment. | No workaround. |
STL-73709 | The | No workaround. |
STL-73669 | Executing | The message may be ignored. |
STL-73531 | Configuring more than two data VLs is not currently supported. Doing so may lead to incorrect mappings of SC to VL. | Limit the number of configured data VLs to two. |
STL-73401 | During link bring up on a mixed OPA100/CN5000 fabric the FM log may show | These messages and link bounces are expected on mixed fabrics and do not indicate a fault. |
STL-73330 | Some LS-DYNA R14.1.0. benchmarks hang with Open MPI when using the OPX Provider for libfabric. | Set the environment variable FI_OPX_RELIABILITY_SERVICE_USEC_MAX=5000. |
STL-73267 | When running the | No workaround. |
STL-73245 | CN5000 Switch-Switch links do not appear in either | No workaround. |
STL-73215 | When running | Use |
STL-73160 | The comments in the Adaptive Routing section of the opafm.xml file do not explain which settings are required for MGAR or for FGAR. | Currently the only field related to FGAR is
All other fields are related to legacy MGAR and will be ignored if |
STL-73140 | The following CN5000 commands do not work as expected:
| Note the following:
|
STL-73029 | BEL DC power supplies VOUT_MODE command returns incorrect results. | No workaround. |
STL-72864 | High CPU utilization seen for hfi1 related interrupts, potentially impacting performance. | Use process pinning to avoid cores servicing hfi1 interrupts. |
STL-72815 |
| The duplicated entries can be ignored. |
STL-72805 | Enabling vFabrics with QoS results in | No workaround. Port bounces are part of the standard recovery mechanism. These messages should only occur once and only when there is a change in the SCVL maps. |
STL-72758 | Cableinfo errors may appear in the log file. | To suppress
|
STL-72673 | OS-release file captured by opacapture is empty. | Use |
STL-72649 | An Open MPI error may occur when using | Contact support@cornelis.com. |
STL-72622 |
| No workaround. This is informational. |
STL-72583 STL-72640 | In some cases the dmesg log may contain a message stating:
| This is cosmetic and will not affect functionality. |
STL-72575 | TID updates under heavy load may result in an | Reload the hfi1 driver with the module parameter |
STL-72573 | Hangs and errors have been seen in the OSU alltoall collective test when using the OPX Provider to libfabric with ROCm. | No workaround. |
STL-72572 | In | No workaround. |
STL-72555 |
| Use |
STL-72547 | Class Port Info queries are not reporting properly. | No workaround. |
STL-72541 | Running the | These errors can be ignored. |
STL-72536 STL-72537 | CableInfo errors encountered when using the | Cable information reporting not currently supported. |
STL-72526 | The Fabric Manager system log port numbering is different from Switch CLI command port numbering. | The port number used by the FM is equivalent to twice the switch CLI port name minus one. Contact Cornelis Customer Support for details. |
STL-72523 | Errors occur on RHEL 9.5 after installation of meta package. | Refer to Disable the Repository After OPX Software Installation. |
STL-72431 | The command | Use |
STL-72420 | On some versions of RHEL 9.x, there is a known failure (rdmavt driver deadlock.) recorded in https://issues.redhat.com/browse/RHEL-83851. NOTE: Cornelis has not replicated this problem but it is possible that customers may be affected. | No workaround. |
STL-72205 | FI_OPX_HFI_SELECT=[] does not correctly map to the available adapter in the case in which other adapters in the system have been disabled. | Unload and reload the driver. |
STL-72160 | After uninstalling the meta packages with a package manager, several Cornelis Networks packages remain. | Refer to the CN5000 Maintenance and Troubleshooting Guide, “Remove OPX Software from a Host” for removal of the remaining packages. |
STL-71364 STL-72423 | Some legacy Omni-Path host utilities have been deprecated for CN5000 but are still supported for OPA100. | For a list of commands supported for CN5000, refer to the Man Pages or CN5000 Commands Guide. |
STL-70422 | RCCL hangs on AMD GPUs with opx and aws-ofi-rccl plugin. | Use Verbs over OPX Provider when using RCCL. |
STL-67178 | After boot, the OPX Software hfi1-NVIDIA support is not available. | Review boot configuration to ensure that nvidia-driver will be available when hfi1 is loaded. |
STL-66199 | On RHEL 9.x, the Invalid MAD: Invalid Session ID Error: Failed to get ini descriptors - status 3 Error: Failed to acquire node description - status -1 Invalid MAD: Invalid Session ID Error: Failed to get ini descriptors - status 3 | Perform the following:
|
Product Limitations
This release has the following limitations:
Queries to single port adapters will reflect that there are two ports with the first port always showing as offline.
Running of MPI jobs across both CN5000 and OPA100 components in hybrid fabrics (fabrics where CN5000 and OPA100 are connected), is not presently supported.
In the opafm.xml file, the default HFI port for fm0 must be set to "2" for proper operation:
<Name>fm0</Name> <Hfi>1</Hfi> <Port>2</Port>Non-default
MinShareVLMemandDedicatedVLMemvalues are not supported. Only use default values.FM Failover is presently not supported. Use a single Fabric Manager.
When the PM is enabled and there is a disabled SuperNIC port in the fabric, a segfault may occur in the SM. Enable all disabled SuperNIC ports or disable the PM. Note that the SM will restart and the SM/PM will recover.
NVMe over Fabric is currently not supported.
ROCm 6.x is required when using AMD GPUs on RHEL/Rocky 9.4, 9.5 and 9.6.
Some distros versions may ship with ib_qib driver enabled. This driver is incompatible with the CN5000 OPX Software and may result in errors such as
disagrees about version of symbolin logs. Setblacklist ib_qib.